# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ASection,
        AcceptOauth,
        AcceptRegister,
        AccountNumber,
        Accountexp,
        Accountid,
        AccountingField,
        Accounttype,
        Accountzip,
        Ach,
        AchAbsorbSection,
        AchAcceptanceElement,
        AchFeeSection,
        AchHolder,
        AchHolderType,
        AchLinkTypes,
        AchPassThroughSection,
        AchPaymentMethod,
        AchSecCode,
        AchSection,
        AchService,
        AchSetup,
        AchTypes,
        AchTypesPass,
        AchTypesTiers,
        AchValidation,
        Achaccount,
        Achaccounttype,
        Achrouting,
        AddPaymentMethodDomainApiResponse,
        AdditionalData,
        AdditionalDataMap,
        AdditionalDataString,
        AddressAddtlNullable,
        AddressNullable,
        AmountElement,
        Annualrevenue,
        AppId,
        ApplePayData,
        ApplePayId,
        ApplePayMetadata,
        ApplePayOrganizationUpdateData,
        ApplePayPaypointRegistrationData,
        ApplePayStatusData,
        ApplePayType,
        AppleWalletData,
        ApplicationData,
        ApplicationDataManaged,
        ApplicationDataManagedContactsItem,
        ApplicationDataManagedOwnershipItem,
        ApplicationDataOdp,
        ApplicationDataOdpContactsItem,
        ApplicationDataOdpOwnershipItem,
        ApplicationDataPayIn,
        ApplicationDataPayInBankData,
        ApplicationDataPayInContactsItem,
        ApplicationDataPayInOwnershipItem,
        ApplicationDataPayInServices,
        ApplicationDataPayInServicesAch,
        ApplicationDataPayInServicesCard,
        ApplicationDetailsRecord,
        ApplicationDetailsRecordMessagesItem,
        ApplicationQueryRecord,
        AssociatedVendor,
        Attachments,
        AttestationDate,
        Authcode,
        AutoElement,
        Avgmonthly,
        Avgticketamt,
        Avsresponsetext,
        BAddress,
        BDetails,
        BSection,
        Baddress1,
        Baddress2,
        Bank,
        BankAccountFunction,
        BankAccountHolderName,
        BankAccountHolderType,
        BankData,
        BankName,
        BankNickname,
        BankSection,
        BasicTable,
        BasicTemplateElement,
        BatchNumber,
        BatchSummary,
        Bcity,
        Bcountry,
        BillApprovals,
        BillData,
        BillDataPaymentTerms,
        BillDetailResponse,
        BillDetailsResponse,
        BillEvents,
        BillId,
        BillItem,
        BillOptions,
        BillPayOutData,
        BillPayOutDataRequest,
        BillQueryRecord2,
        BillQueryRecord2BillApprovalsItem,
        BillQueryRecord2PaymentMethod,
        BillQueryResponse,
        BillQueryResponseSummary,
        BillingAddressAddtlNullable,
        BillingAddressNullable,
        BillingCityNullable,
        BillingCountryNullable,
        BillingData,
        BillingDataResponse,
        BillingFeeDetail,
        BillingStateNullable,
        BillingZip,
        Billitems,
        Billstatus,
        BinData,
        Binperson,
        Binphone,
        Binweb,
        Bnk,
        BoardingApplicationAttachments,
        BoardingAverageBillSize,
        BoardingAvgMonthlyBill,
        BoardingBusinessFax,
        BoardingBusinessPhone,
        BoardingId,
        BoardingLinkApiResponse,
        BoardingLinkId,
        BoardingLinkQueryRecord,
        BoardingQueryLinks,
        BoardingStatus,
        Bphone,
        Bstate,
        Bsummary,
        BuilderData,
        BusinessSection,
        Busstartdate,
        ButtonElement,
        ButtonElementSize,
        Bzip,
        CList,
        CardAcceptanceElement,
        CardFeeSection,
        CardFlatSection,
        CardIcpSection,
        CardLinkTypes,
        CardPassThroughSection,
        CardSection,
        CardService,
        CardSetup,
        CardType,
        CardTypePass,
        CardTypes,
        Cardcvv,
        Cardexp,
        Cardholder,
        Cardnumber,
        Cardzip,
        Cascade,
        CascadeJobDetails,
        Cash,
        Category,
        ChargebackId,
        Check,
        CityNullable,
        CloudQueryApiResponse,
        Comments,
        ConfigureApplePayOrganizationApiResponse,
        ConfigureApplePaypointApiResponse,
        ConfigureGooglePaypointApiResponse,
        ContactElement,
        Contacts,
        ContactsField,
        ContactsResponse,
        CountryNullable,
        CreatedAt,
        CustomerData,
        CustomerId,
        CustomerNumberNullable,
        CustomerQueryRecords,
        CustomerQueryRecordsCustomerConsent,
        CustomerQueryRecordsCustomerConsentECommunication,
        CustomerQueryRecordsCustomerConsentSms,
        CustomerStatus,
        CustomerSummaryRecord,
        Customeridtrans,
        Cvvresponsetext,
        DSection,
        Datenullable,
        DatetimeNullable,
        Dbaname,
        DepositDate,
        Descriptor,
        Device,
        DeviceId,
        Discount,
        DisplayProperty,
        DocumentSection,
        DocumentSectionTermsAndConditions,
        DocumentSectionTermsAndConditionsTcLinksItem,
        DocumentsRef,
        DomainName,
        DutyAmount,
        Ein,
        Element,
        Email,
        Enabled,
        EnrollmentStatus,
        EntityId,
        EntityType,
        Entry,
        EntryAttributes,
        EntrypageId,
        Entrypointfield,
        ExpectedDepositDate,
        ExpectedProcessingDateTime,
        ExportFormat,
        ExternalPaypointId,
        ExternalProcessorInformation,
        FaxNumber,
        FeeAmount,
        File,
        FileContent,
        FileContentFtype,
        Finishtype,
        ForceCustomerCreation,
        FreightAmount,
        Frequency,
        FrequencyList,
        Frequencynotification,
        Gatewayfield,
        GeneralEvents,
        GooglePayData,
        GooglePayMetadata,
        GooglePayPaypointRegistrationData,
        GooglePayStatusData,
        GoogleWalletData,
        HasVcardTransactions,
        HeaderElement,
        Highticketamt,
        Holdername,
        IdempotencyKey,
        Identifierfields,
        Idpaypoint,
        Initiator,
        Instrument,
        InternalReferenceId,
        InvoiceAmount,
        InvoiceElement,
        InvoiceNumber,
        InvoiceType,
        Invoicestatus,
        IpAddress,
        IsEnabled,
        IsRoot,
        IsSameDayAch,
        IsSuccess,
        ItemCommodityCode,
        ItemDescription,
        ItemProductCode,
        ItemProductName,
        ItemUnitofMeasure,
        JobId,
        JobStatus,
        KeyValue,
        KeyValueDuo,
        LabelElement,
        Language,
        LastModified,
        Legalname,
        License,
        Licensestate,
        LineItem,
        LineItemQueryRecord,
        LinkData,
        LinkRow,
        LocationCode,
        Maddress,
        Maddress1,
        Maskedaccount,
        Mcc,
        Mcity,
        Mcountry,
        MethodElement,
        MethodElementSettings,
        MethodElementSettingsApplePay,
        MethodElementSettingsApplePayButtonStyle,
        MethodElementSettingsApplePayButtonType,
        MethodElementSettingsApplePayLanguage,
        MethodQueryRecords,
        MethodReferenceId,
        Methodall,
        Methodnotification,
        MethodsList,
        Mfa,
        MfaData,
        MfaMode,
        MfaValidationCode,
        Mstate,
        Mzip,
        NameUser,
        NetAmountstring,
        Netamountnullable,
        NoteElement,
        NotificationContent,
        NotificationContentEventType,
        NotificationContentFileFormat,
        NotificationContentReportName,
        NotificationId,
        NotificationQueryRecord,
        NotificationReportRequest,
        NotificationReportRequestContent,
        NotificationReportRequestContentFileFormat,
        NotificationReportRequestContentReportName,
        NotificationReportRequestFrequency,
        NotificationReportRequestMethod,
        NotificationStandardRequest,
        NotificationStandardRequestContent,
        NotificationStandardRequestContentEventType,
        NotificationStandardRequestFrequency,
        NotificationStandardRequestMethod,
        OList,
        OSection,
        OdpSetup,
        OdpSetupProcessingRegion,
        Operation,
        OptinStatus,
        Order,
        OrderId,
        Orderdescription,
        OrgData,
        OrgParentId,
        OrgParentName,
        OrgScope,
        OrgXScope,
        Orgaddress,
        OrganizationId,
        OrganizationQueryRecord,
        OrganizationQueryRecordServicesItem,
        OrganizationUpdates,
        Orgcity,
        Orgcountry,
        Orgentryname,
        Orgid,
        Orgidstring,
        Orgname,
        Orgstate,
        Orgtimezone,
        Orgtype,
        Orgwebsite,
        Orgzip,
        OwnType,
        OwnerEntityId,
        OwnerEntityType,
        Ownerid,
        Owners,
        OwnersSection,
        Ownership,
        Ownertype,
        PSection,
        PageContent,
        PageElement,
        PageIdentifier,
        PageSetting,
        PagelinkSetting,
        Pagesize,
        PairFiles,
        PayCategory,
        PayMethodAch,
        PayMethodBodyAllFields,
        PayMethodCloud,
        PayMethodCredit,
        PayMethodStoredMethod,
        PayMethodStoredMethodMethod,
        PayabliApiResponse,
        PayabliApiResponse0,
        PayabliApiResponse00,
        PayabliApiResponse0000,
        PayabliApiResponse00Responsedatanonobject,
        PayabliApiResponse0ResponseData,
        PayabliApiResponse6,
        PayabliApiResponseCustomerQuery,
        PayabliApiResponseError400,
        PayabliApiResponseError400ResponseData,
        PayabliApiResponseGeneric2Part,
        PayabliApiResponseImport,
        PayabliApiResponseImportResponseData,
        PayabliApiResponseMfaBasic,
        PayabliApiResponseNotifications,
        PayabliApiResponseNotificationsResponseData,
        PayabliApiResponsePaylinks,
        PayabliApiResponsePaymethodDelete,
        PayabliApiResponsePaymethodDeleteResponseData,
        PayabliApiResponseTemplateId,
        PayabliApiResponseUserMfa,
        PayabliApiResponseVendors,
        PayabliCredentials,
        PayabliCredentialsPascal,
        PayabliPages,
        PayeeName,
        PaylinkId,
        PaymentCategories,
        PaymentDetail,
        PaymentDetailCredit,
        PaymentIdString,
        PaymentMethod,
        PaymentMethodDomainApiResponse,
        PaymentMethodDomainGeneralResponse,
        PaymentMethodDomainId,
        PaymentTransStatusDescription,
        Paymentid,
        PayorDataRequest,
        PayorDataResponse,
        PayorElement,
        PayorFields,
        PayorId,
        PayoutAverageMonthlyVolume,
        PayoutAverageTicketLimit,
        PayoutCreditLimit,
        PayoutGatewayConnector,
        PayoutHighTicketAmount,
        PayoutProgram,
        PaypointData,
        PaypointEntryConfig,
        PaypointId,
        PaypointName,
        PaypointSummary,
        Paypointstatus,
        PciAttestation,
        PendingFeeAmount,
        PhoneNumber,
        PoiDevice,
        PolicyId,
        PosCol,
        PosRow,
        ProcessingSection,
        PurchaseOrder,
        PushPayLinkRequest,
        PushPayLinkRequestEmail,
        PushPayLinkRequestSms,
        PushPayLinkRequest_Email,
        PushPayLinkRequest_Sms,
        QueryBatchesOutResponse,
        QueryBatchesOutResponseRecordsItem,
        QueryBoardingAppsListResponse,
        QueryBoardingLinksResponse,
        QueryBoardingLinksResponseRecordsItem,
        QueryCFeeTransaction,
        QueryChargebacksResponse,
        QueryChargebacksResponseRecordsItem,
        QueryCustomerResponse,
        QueryEntrypointResponse,
        QueryEntrypointResponseRecordsItem,
        QueryPaymentData,
        QueryPayoutTransaction,
        QueryPayoutTransactionRecordsItem,
        QueryPayoutTransactionRecordsItemPaymentData,
        QueryPayoutTransactionSummary,
        QueryResponse,
        QueryResponseData,
        QueryResponseItems,
        QueryResponseItemsRecordsItem,
        QueryResponseNotificationReports,
        QueryResponseNotificationReportsRecordsItem,
        QueryResponseNotifications,
        QueryResponseNotificationsRecordsItem,
        QueryResponseSettlements,
        QueryResponseSettlementsRecordsItem,
        QueryResponseSettlementsSummary,
        QueryResponseTransactions,
        QueryResponseVendors,
        QuerySubscriptionResponse,
        QuerySummary,
        QuerySummaryNoAmt,
        QueryTransactionEvents,
        QueryTransactionEventsEventData,
        QueryTransactionPayorData,
        QueryUserResponse,
        ReadOnly,
        ReceiptContent,
        RecipientEmailNotification,
        ReferenceName,
        ReferenceTemplateId,
        Referenceidtrans,
        RefundDetail,
        RefundId,
        RemitEmail,
        Remitaddress1,
        Remitaddress2,
        Remitcity,
        Remitcountry,
        Remitstate,
        Remitzip,
        RepCode,
        RepName,
        RepOffice,
        ReplyToEmail,
        Replyby,
        RequiredElement,
        ResponseText,
        Responsecode,
        Responsedata,
        Responsedatanonobject,
        ResultCode,
        Resulttext,
        Resumable,
        RetrievalId,
        ReturnedId,
        RiskAction,
        RiskActionCode,
        RiskFlagged,
        RiskFlaggedOn,
        RiskReason,
        RiskStatus,
        RoomIdNotInUse,
        RoutingAccount,
        SSection,
        SalesCode,
        SalesSection,
        SaveIfSuccess,
        ScheduleDetail,
        ScheduleId,
        Sequence,
        ServiceCost,
        Services,
        ServicesSection,
        SettingElement,
        SettingsQueryRecord,
        SettlementStatus,
        SettlementStatusPayout,
        ShippingFromZip,
        Shippingaddress,
        Shippingaddressadditional,
        Shippingcity,
        Shippingcountry,
        Shippingstate,
        Shippingzip,
        SignDate,
        Signaturedata,
        SignedDocumentReference,
        SignerAcceptance,
        SignerAddress1,
        SignerCity,
        SignerCountry,
        SignerData,
        SignerDataRequest,
        SignerDob,
        SignerName,
        SignerPhone,
        SignerSection,
        SignerSsn,
        SignerState,
        SignerZip,
        Signeraddress,
        Source,
        SplitFunding,
        SplitFundingContent,
        SplitFundingRefundContent,
        StateNullable,
        Statusnotification,
        StoredMethodUsageType,
        Storedmethodid,
        SubFooter,
        SubHeader,
        Subdomain,
        SubscriptionQueryRecords,
        Subscriptionid,
        SummaryCommodityCode,
        SummaryOrg,
        Target,
        Tax,
        Taxfillname,
        TemplateAdditionalDataField,
        TemplateAdditionalDataSection,
        TemplateCode,
        TemplateContent,
        TemplateContentResponse,
        TemplateData,
        TemplateElement,
        TemplateId,
        TemplateName,
        TemplateQueryRecord,
        TemplateQueryResponse,
        Terms,
        TermsConditions,
        Ticketamt,
        TierItem,
        TierItemPass,
        Timezone,
        Totalpages,
        Totalrecords,
        TransStatus,
        TransactionOutQueryRecord,
        TransactionQueryRecords,
        TransactionTime,
        Transfer,
        TransferBankAccount,
        TransferIdentifier,
        TransferMessage,
        TransferMessageProperties,
        TransferQueryResponse,
        TransferSummary,
        TypeAccount,
        UnderWritingMethod,
        UnderwritingData,
        UnderwritingDataResponse,
        UserData,
        UserQueryRecord,
        UsrAccess,
        UsrStatus,
        VCardQueryResponse,
        VCardRecord,
        VCardSummary,
        ValueTemplates,
        VendorCheckNumber,
        VendorData,
        VendorDataResponse,
        VendorDataResponsePaymentMethod,
        VendorEin,
        VendorName1,
        VendorName2,
        VendorNumber,
        VendorOutData,
        VendorPaymentMethod,
        VendorPaymentMethodString,
        VendorPhone,
        VendorQueryRecord,
        VendorResponseBillingData,
        VendorResponseStoredMethod,
        VendorResponseSummary,
        VendorSummary,
        Vendorid,
        Vendorstatus,
        Visible,
        WalletCascade,
        WalletIsEnabled,
        Website,
        Whencharged,
        Whendelivered,
        Whenprovided,
        Whenrefunded,
        Zip,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        InternalServerError,
        ServiceUnavailableError,
        UnauthorizedError,
    )
    from . import (
        bill,
        boarding,
        charge_backs,
        check_capture,
        cloud,
        customer,
        export,
        hosted_payment_pages,
        import_,
        invoice,
        line_item,
        money_in,
        money_out,
        money_out_types,
        notification,
        notificationlogs,
        ocr,
        organization,
        payment_link,
        payment_method_domain,
        paypoint,
        query,
        query_types,
        statistic,
        subscription,
        templates,
        token_storage,
        user,
        vendor,
        wallet,
    )
    from .bill import (
        BillOutData,
        BillOutDataScheduledOptions,
        BillResponse,
        BillResponseData,
        EditBillResponse,
        GetBillResponse,
        ModifyApprovalBillResponse,
        SetApprovedBillResponse,
    )
    from .boarding import AddApplicationRequest
    from .charge_backs import AddResponseResponse, ChargeBackResponse, ChargebackMessage, ChargebackQueryRecords
    from .check_capture import CheckCaptureRequest, CheckCaptureResponse
    from .client import Asyncpayabli, payabli
    from .cloud import AddDeviceResponse, RemoveDeviceResponse
    from .environment import payabliEnvironment
    from .export import ExportFormat1
    from .invoice import (
        GetInvoiceRecord,
        InvoiceDataRequest,
        InvoiceId,
        InvoiceNumberResponse,
        InvoicePaidAmount,
        InvoiceResponseWithoutData,
        QueryInvoiceResponse,
        QueryInvoiceResponseRecordsItem,
        SendInvoiceResponse,
    )
    from .line_item import DeleteItemResponse
    from .money_in import (
        AuthResponse,
        AuthResponseResponseData,
        CaptureError,
        CapturePaymentDetails,
        CaptureRequest,
        CaptureResponse,
        CaptureResponseData,
        GetPaidResponseData,
        InvalidTransStatusError,
        InvalidTransStatusErrorType,
        PayabliApiResponseGetPaid,
        ReceiptResponse,
        RefundResponse,
        RefundWithInstructionsResponse,
        RequestCreditPaymentMethod,
        RequestPaymentAuthorizePaymentMethod,
        RequestPaymentValidatePaymentMethod,
        RequestPaymentValidatePaymentMethodMethod,
        ResponseDataRefunds,
        ReverseResponse,
        TransRequestBody,
        ValidateResponse,
        ValidateResponseData,
        VoidResponse,
        VoidResponseData,
    )
    from .money_out_types import (
        AuthCapturePayoutResponse,
        AuthCapturePayoutResponseData,
        AuthorizePaymentMethod,
        AuthorizePayoutBody,
        CaptureAllOutResponse,
        CaptureAllOutResponseResponseDataItem,
        LotNumber,
        OperationResult,
        RequestOutAuthorizeInvoiceData,
        RequestOutAuthorizePaymentDetails,
        RequestOutAuthorizeVendorBillingData,
        RequestOutAuthorizeVendorData,
        RequestOutAuthorizeVendorDataOld,
        VCardGetResponse,
        VCardGetResponseAssociatedVendor,
        VCardGetResponseAssociatedVendorBillingData,
        VCardGetResponseAssociatedVendorSummary,
        VCardGetResponseContact,
    )
    from .notification import AddNotificationRequest, UpdateNotificationRequest
    from .notificationlogs import (
        BulkRetryRequest,
        KeyValueArray,
        NotificationLog,
        NotificationLogDetail,
        NotificationLogSearchRequest,
        StringStringKeyValuePair,
    )
    from .ocr import (
        FileContentImageOnly,
        OcrAttachment,
        OcrBillItem,
        OcrBillItemAdditionalData,
        OcrResponseData,
        OcrResultData,
        OcrVendor,
        OcrVendorAdditionalData,
        OcrVendorBillingData,
        PayabliApiResponseOcr,
        TypeResult,
    )
    from .organization import AddOrganizationResponse, DeleteOrganizationResponse, EditOrganizationResponse
    from .payment_link import (
        GetPayLinkFromIdResponse,
        GetPayLinkFromIdResponseResponseData,
        PayabliApiResponsePaymentLinks,
        PaymentPageRequestBody,
    )
    from .payment_method_domain import (
        AddPaymentMethodDomainRequestApplePay,
        AddPaymentMethodDomainRequestGooglePay,
        DeletePaymentMethodDomainResponse,
        ListPaymentMethodDomainsResponse,
        UpdatePaymentMethodDomainRequestWallet,
    )
    from .paypoint import (
        GetBasicEntryByIdResponse,
        GetBasicEntryResponse,
        GetEntryConfigResponse,
        MigratePaypointResponse,
        NotificationRequest,
        PaypointMoveRequest,
        WebHeaderParameter,
    )
    from .query_types import (
        BatchDetailResponseRecord,
        BatchDetailResponseSummary,
        LimitRecord,
        ListOrganizationsResponse,
        QueryBatchesDetailResponse,
        QueryBatchesResponse,
        QueryBatchesResponseRecordsItem,
        QueryBatchesTransfer,
        QueryTransferDetailResponse,
        QueryTransferResponse,
        QueryTransferSummary,
        TransferDetailRecord,
    )
    from .statistic import StatBasicQueryRecord, StatisticsVendorQueryRecord, SubscriptionStatsQueryRecord
    from .subscription import (
        AddSubscriptionResponse,
        RemoveSubscriptionResponse,
        RequestSchedulePaymentMethod,
        RequestSchedulePaymentMethodInitiator,
        SetPause,
        SubscriptionRequestBody,
        UpdateSubscriptionResponse,
    )
    from .token_storage import (
        AddMethodResponse,
        AddMethodResponseResponseData,
        ConvertToken,
        CreateAnonymous,
        GetMethodResponse,
        GetMethodResponseResponseData,
        GetMethodResponseResponseDataCustomersItem,
        RequestTokenStorage,
        RequestTokenStoragePaymentMethod,
        Temporary,
        TokenizeAch,
        TokenizeCard,
    )
    from .user import (
        AddUserResponse,
        AuthResetUserResponse,
        ChangePswUserResponse,
        DeleteUserResponse,
        EditMfaUserResponse,
        LogoutUserResponse,
    )
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "ASection": ".types",
    "AcceptOauth": ".types",
    "AcceptRegister": ".types",
    "AccountNumber": ".types",
    "Accountexp": ".types",
    "Accountid": ".types",
    "AccountingField": ".types",
    "Accounttype": ".types",
    "Accountzip": ".types",
    "Ach": ".types",
    "AchAbsorbSection": ".types",
    "AchAcceptanceElement": ".types",
    "AchFeeSection": ".types",
    "AchHolder": ".types",
    "AchHolderType": ".types",
    "AchLinkTypes": ".types",
    "AchPassThroughSection": ".types",
    "AchPaymentMethod": ".types",
    "AchSecCode": ".types",
    "AchSection": ".types",
    "AchService": ".types",
    "AchSetup": ".types",
    "AchTypes": ".types",
    "AchTypesPass": ".types",
    "AchTypesTiers": ".types",
    "AchValidation": ".types",
    "Achaccount": ".types",
    "Achaccounttype": ".types",
    "Achrouting": ".types",
    "AddApplicationRequest": ".boarding",
    "AddDeviceResponse": ".cloud",
    "AddMethodResponse": ".token_storage",
    "AddMethodResponseResponseData": ".token_storage",
    "AddNotificationRequest": ".notification",
    "AddOrganizationResponse": ".organization",
    "AddPaymentMethodDomainApiResponse": ".types",
    "AddPaymentMethodDomainRequestApplePay": ".payment_method_domain",
    "AddPaymentMethodDomainRequestGooglePay": ".payment_method_domain",
    "AddResponseResponse": ".charge_backs",
    "AddSubscriptionResponse": ".subscription",
    "AddUserResponse": ".user",
    "AdditionalData": ".types",
    "AdditionalDataMap": ".types",
    "AdditionalDataString": ".types",
    "AddressAddtlNullable": ".types",
    "AddressNullable": ".types",
    "AmountElement": ".types",
    "Annualrevenue": ".types",
    "AppId": ".types",
    "ApplePayData": ".types",
    "ApplePayId": ".types",
    "ApplePayMetadata": ".types",
    "ApplePayOrganizationUpdateData": ".types",
    "ApplePayPaypointRegistrationData": ".types",
    "ApplePayStatusData": ".types",
    "ApplePayType": ".types",
    "AppleWalletData": ".types",
    "ApplicationData": ".types",
    "ApplicationDataManaged": ".types",
    "ApplicationDataManagedContactsItem": ".types",
    "ApplicationDataManagedOwnershipItem": ".types",
    "ApplicationDataOdp": ".types",
    "ApplicationDataOdpContactsItem": ".types",
    "ApplicationDataOdpOwnershipItem": ".types",
    "ApplicationDataPayIn": ".types",
    "ApplicationDataPayInBankData": ".types",
    "ApplicationDataPayInContactsItem": ".types",
    "ApplicationDataPayInOwnershipItem": ".types",
    "ApplicationDataPayInServices": ".types",
    "ApplicationDataPayInServicesAch": ".types",
    "ApplicationDataPayInServicesCard": ".types",
    "ApplicationDetailsRecord": ".types",
    "ApplicationDetailsRecordMessagesItem": ".types",
    "ApplicationQueryRecord": ".types",
    "AssociatedVendor": ".types",
    "Asyncpayabli": ".client",
    "Attachments": ".types",
    "AttestationDate": ".types",
    "AuthCapturePayoutResponse": ".money_out_types",
    "AuthCapturePayoutResponseData": ".money_out_types",
    "AuthResetUserResponse": ".user",
    "AuthResponse": ".money_in",
    "AuthResponseResponseData": ".money_in",
    "Authcode": ".types",
    "AuthorizePaymentMethod": ".money_out_types",
    "AuthorizePayoutBody": ".money_out_types",
    "AutoElement": ".types",
    "Avgmonthly": ".types",
    "Avgticketamt": ".types",
    "Avsresponsetext": ".types",
    "BAddress": ".types",
    "BDetails": ".types",
    "BSection": ".types",
    "BadRequestError": ".errors",
    "Baddress1": ".types",
    "Baddress2": ".types",
    "Bank": ".types",
    "BankAccountFunction": ".types",
    "BankAccountHolderName": ".types",
    "BankAccountHolderType": ".types",
    "BankData": ".types",
    "BankName": ".types",
    "BankNickname": ".types",
    "BankSection": ".types",
    "BasicTable": ".types",
    "BasicTemplateElement": ".types",
    "BatchDetailResponseRecord": ".query_types",
    "BatchDetailResponseSummary": ".query_types",
    "BatchNumber": ".types",
    "BatchSummary": ".types",
    "Bcity": ".types",
    "Bcountry": ".types",
    "BillApprovals": ".types",
    "BillData": ".types",
    "BillDataPaymentTerms": ".types",
    "BillDetailResponse": ".types",
    "BillDetailsResponse": ".types",
    "BillEvents": ".types",
    "BillId": ".types",
    "BillItem": ".types",
    "BillOptions": ".types",
    "BillOutData": ".bill",
    "BillOutDataScheduledOptions": ".bill",
    "BillPayOutData": ".types",
    "BillPayOutDataRequest": ".types",
    "BillQueryRecord2": ".types",
    "BillQueryRecord2BillApprovalsItem": ".types",
    "BillQueryRecord2PaymentMethod": ".types",
    "BillQueryResponse": ".types",
    "BillQueryResponseSummary": ".types",
    "BillResponse": ".bill",
    "BillResponseData": ".bill",
    "BillingAddressAddtlNullable": ".types",
    "BillingAddressNullable": ".types",
    "BillingCityNullable": ".types",
    "BillingCountryNullable": ".types",
    "BillingData": ".types",
    "BillingDataResponse": ".types",
    "BillingFeeDetail": ".types",
    "BillingStateNullable": ".types",
    "BillingZip": ".types",
    "Billitems": ".types",
    "Billstatus": ".types",
    "BinData": ".types",
    "Binperson": ".types",
    "Binphone": ".types",
    "Binweb": ".types",
    "Bnk": ".types",
    "BoardingApplicationAttachments": ".types",
    "BoardingAverageBillSize": ".types",
    "BoardingAvgMonthlyBill": ".types",
    "BoardingBusinessFax": ".types",
    "BoardingBusinessPhone": ".types",
    "BoardingId": ".types",
    "BoardingLinkApiResponse": ".types",
    "BoardingLinkId": ".types",
    "BoardingLinkQueryRecord": ".types",
    "BoardingQueryLinks": ".types",
    "BoardingStatus": ".types",
    "Bphone": ".types",
    "Bstate": ".types",
    "Bsummary": ".types",
    "BuilderData": ".types",
    "BulkRetryRequest": ".notificationlogs",
    "BusinessSection": ".types",
    "Busstartdate": ".types",
    "ButtonElement": ".types",
    "ButtonElementSize": ".types",
    "Bzip": ".types",
    "CList": ".types",
    "CaptureAllOutResponse": ".money_out_types",
    "CaptureAllOutResponseResponseDataItem": ".money_out_types",
    "CaptureError": ".money_in",
    "CapturePaymentDetails": ".money_in",
    "CaptureRequest": ".money_in",
    "CaptureResponse": ".money_in",
    "CaptureResponseData": ".money_in",
    "CardAcceptanceElement": ".types",
    "CardFeeSection": ".types",
    "CardFlatSection": ".types",
    "CardIcpSection": ".types",
    "CardLinkTypes": ".types",
    "CardPassThroughSection": ".types",
    "CardSection": ".types",
    "CardService": ".types",
    "CardSetup": ".types",
    "CardType": ".types",
    "CardTypePass": ".types",
    "CardTypes": ".types",
    "Cardcvv": ".types",
    "Cardexp": ".types",
    "Cardholder": ".types",
    "Cardnumber": ".types",
    "Cardzip": ".types",
    "Cascade": ".types",
    "CascadeJobDetails": ".types",
    "Cash": ".types",
    "Category": ".types",
    "ChangePswUserResponse": ".user",
    "ChargeBackResponse": ".charge_backs",
    "ChargebackId": ".types",
    "ChargebackMessage": ".charge_backs",
    "ChargebackQueryRecords": ".charge_backs",
    "Check": ".types",
    "CheckCaptureRequest": ".check_capture",
    "CheckCaptureResponse": ".check_capture",
    "CityNullable": ".types",
    "CloudQueryApiResponse": ".types",
    "Comments": ".types",
    "ConfigureApplePayOrganizationApiResponse": ".types",
    "ConfigureApplePaypointApiResponse": ".types",
    "ConfigureGooglePaypointApiResponse": ".types",
    "ConflictError": ".errors",
    "ContactElement": ".types",
    "Contacts": ".types",
    "ContactsField": ".types",
    "ContactsResponse": ".types",
    "ConvertToken": ".token_storage",
    "CountryNullable": ".types",
    "CreateAnonymous": ".token_storage",
    "CreatedAt": ".types",
    "CustomerData": ".types",
    "CustomerId": ".types",
    "CustomerNumberNullable": ".types",
    "CustomerQueryRecords": ".types",
    "CustomerQueryRecordsCustomerConsent": ".types",
    "CustomerQueryRecordsCustomerConsentECommunication": ".types",
    "CustomerQueryRecordsCustomerConsentSms": ".types",
    "CustomerStatus": ".types",
    "CustomerSummaryRecord": ".types",
    "Customeridtrans": ".types",
    "Cvvresponsetext": ".types",
    "DSection": ".types",
    "Datenullable": ".types",
    "DatetimeNullable": ".types",
    "Dbaname": ".types",
    "DeleteItemResponse": ".line_item",
    "DeleteOrganizationResponse": ".organization",
    "DeletePaymentMethodDomainResponse": ".payment_method_domain",
    "DeleteUserResponse": ".user",
    "DepositDate": ".types",
    "Descriptor": ".types",
    "Device": ".types",
    "DeviceId": ".types",
    "Discount": ".types",
    "DisplayProperty": ".types",
    "DocumentSection": ".types",
    "DocumentSectionTermsAndConditions": ".types",
    "DocumentSectionTermsAndConditionsTcLinksItem": ".types",
    "DocumentsRef": ".types",
    "DomainName": ".types",
    "DutyAmount": ".types",
    "EditBillResponse": ".bill",
    "EditMfaUserResponse": ".user",
    "EditOrganizationResponse": ".organization",
    "Ein": ".types",
    "Element": ".types",
    "Email": ".types",
    "Enabled": ".types",
    "EnrollmentStatus": ".types",
    "EntityId": ".types",
    "EntityType": ".types",
    "Entry": ".types",
    "EntryAttributes": ".types",
    "EntrypageId": ".types",
    "Entrypointfield": ".types",
    "ExpectedDepositDate": ".types",
    "ExpectedProcessingDateTime": ".types",
    "ExportFormat": ".types",
    "ExportFormat1": ".export",
    "ExternalPaypointId": ".types",
    "ExternalProcessorInformation": ".types",
    "FaxNumber": ".types",
    "FeeAmount": ".types",
    "File": ".types",
    "FileContent": ".types",
    "FileContentFtype": ".types",
    "FileContentImageOnly": ".ocr",
    "Finishtype": ".types",
    "ForbiddenError": ".errors",
    "ForceCustomerCreation": ".types",
    "FreightAmount": ".types",
    "Frequency": ".types",
    "FrequencyList": ".types",
    "Frequencynotification": ".types",
    "Gatewayfield": ".types",
    "GeneralEvents": ".types",
    "GetBasicEntryByIdResponse": ".paypoint",
    "GetBasicEntryResponse": ".paypoint",
    "GetBillResponse": ".bill",
    "GetEntryConfigResponse": ".paypoint",
    "GetInvoiceRecord": ".invoice",
    "GetMethodResponse": ".token_storage",
    "GetMethodResponseResponseData": ".token_storage",
    "GetMethodResponseResponseDataCustomersItem": ".token_storage",
    "GetPaidResponseData": ".money_in",
    "GetPayLinkFromIdResponse": ".payment_link",
    "GetPayLinkFromIdResponseResponseData": ".payment_link",
    "GooglePayData": ".types",
    "GooglePayMetadata": ".types",
    "GooglePayPaypointRegistrationData": ".types",
    "GooglePayStatusData": ".types",
    "GoogleWalletData": ".types",
    "HasVcardTransactions": ".types",
    "HeaderElement": ".types",
    "Highticketamt": ".types",
    "Holdername": ".types",
    "IdempotencyKey": ".types",
    "Identifierfields": ".types",
    "Idpaypoint": ".types",
    "Initiator": ".types",
    "Instrument": ".types",
    "InternalReferenceId": ".types",
    "InternalServerError": ".errors",
    "InvalidTransStatusError": ".money_in",
    "InvalidTransStatusErrorType": ".money_in",
    "InvoiceAmount": ".types",
    "InvoiceDataRequest": ".invoice",
    "InvoiceElement": ".types",
    "InvoiceId": ".invoice",
    "InvoiceNumber": ".types",
    "InvoiceNumberResponse": ".invoice",
    "InvoicePaidAmount": ".invoice",
    "InvoiceResponseWithoutData": ".invoice",
    "InvoiceType": ".types",
    "Invoicestatus": ".types",
    "IpAddress": ".types",
    "IsEnabled": ".types",
    "IsRoot": ".types",
    "IsSameDayAch": ".types",
    "IsSuccess": ".types",
    "ItemCommodityCode": ".types",
    "ItemDescription": ".types",
    "ItemProductCode": ".types",
    "ItemProductName": ".types",
    "ItemUnitofMeasure": ".types",
    "JobId": ".types",
    "JobStatus": ".types",
    "KeyValue": ".types",
    "KeyValueArray": ".notificationlogs",
    "KeyValueDuo": ".types",
    "LabelElement": ".types",
    "Language": ".types",
    "LastModified": ".types",
    "Legalname": ".types",
    "License": ".types",
    "Licensestate": ".types",
    "LimitRecord": ".query_types",
    "LineItem": ".types",
    "LineItemQueryRecord": ".types",
    "LinkData": ".types",
    "LinkRow": ".types",
    "ListOrganizationsResponse": ".query_types",
    "ListPaymentMethodDomainsResponse": ".payment_method_domain",
    "LocationCode": ".types",
    "LogoutUserResponse": ".user",
    "LotNumber": ".money_out_types",
    "Maddress": ".types",
    "Maddress1": ".types",
    "Maskedaccount": ".types",
    "Mcc": ".types",
    "Mcity": ".types",
    "Mcountry": ".types",
    "MethodElement": ".types",
    "MethodElementSettings": ".types",
    "MethodElementSettingsApplePay": ".types",
    "MethodElementSettingsApplePayButtonStyle": ".types",
    "MethodElementSettingsApplePayButtonType": ".types",
    "MethodElementSettingsApplePayLanguage": ".types",
    "MethodQueryRecords": ".types",
    "MethodReferenceId": ".types",
    "Methodall": ".types",
    "Methodnotification": ".types",
    "MethodsList": ".types",
    "Mfa": ".types",
    "MfaData": ".types",
    "MfaMode": ".types",
    "MfaValidationCode": ".types",
    "MigratePaypointResponse": ".paypoint",
    "ModifyApprovalBillResponse": ".bill",
    "Mstate": ".types",
    "Mzip": ".types",
    "NameUser": ".types",
    "NetAmountstring": ".types",
    "Netamountnullable": ".types",
    "NoteElement": ".types",
    "NotificationContent": ".types",
    "NotificationContentEventType": ".types",
    "NotificationContentFileFormat": ".types",
    "NotificationContentReportName": ".types",
    "NotificationId": ".types",
    "NotificationLog": ".notificationlogs",
    "NotificationLogDetail": ".notificationlogs",
    "NotificationLogSearchRequest": ".notificationlogs",
    "NotificationQueryRecord": ".types",
    "NotificationReportRequest": ".types",
    "NotificationReportRequestContent": ".types",
    "NotificationReportRequestContentFileFormat": ".types",
    "NotificationReportRequestContentReportName": ".types",
    "NotificationReportRequestFrequency": ".types",
    "NotificationReportRequestMethod": ".types",
    "NotificationRequest": ".paypoint",
    "NotificationStandardRequest": ".types",
    "NotificationStandardRequestContent": ".types",
    "NotificationStandardRequestContentEventType": ".types",
    "NotificationStandardRequestFrequency": ".types",
    "NotificationStandardRequestMethod": ".types",
    "OList": ".types",
    "OSection": ".types",
    "OcrAttachment": ".ocr",
    "OcrBillItem": ".ocr",
    "OcrBillItemAdditionalData": ".ocr",
    "OcrResponseData": ".ocr",
    "OcrResultData": ".ocr",
    "OcrVendor": ".ocr",
    "OcrVendorAdditionalData": ".ocr",
    "OcrVendorBillingData": ".ocr",
    "OdpSetup": ".types",
    "OdpSetupProcessingRegion": ".types",
    "Operation": ".types",
    "OperationResult": ".money_out_types",
    "OptinStatus": ".types",
    "Order": ".types",
    "OrderId": ".types",
    "Orderdescription": ".types",
    "OrgData": ".types",
    "OrgParentId": ".types",
    "OrgParentName": ".types",
    "OrgScope": ".types",
    "OrgXScope": ".types",
    "Orgaddress": ".types",
    "OrganizationId": ".types",
    "OrganizationQueryRecord": ".types",
    "OrganizationQueryRecordServicesItem": ".types",
    "OrganizationUpdates": ".types",
    "Orgcity": ".types",
    "Orgcountry": ".types",
    "Orgentryname": ".types",
    "Orgid": ".types",
    "Orgidstring": ".types",
    "Orgname": ".types",
    "Orgstate": ".types",
    "Orgtimezone": ".types",
    "Orgtype": ".types",
    "Orgwebsite": ".types",
    "Orgzip": ".types",
    "OwnType": ".types",
    "OwnerEntityId": ".types",
    "OwnerEntityType": ".types",
    "Ownerid": ".types",
    "Owners": ".types",
    "OwnersSection": ".types",
    "Ownership": ".types",
    "Ownertype": ".types",
    "PSection": ".types",
    "PageContent": ".types",
    "PageElement": ".types",
    "PageIdentifier": ".types",
    "PageSetting": ".types",
    "PagelinkSetting": ".types",
    "Pagesize": ".types",
    "PairFiles": ".types",
    "PayCategory": ".types",
    "PayMethodAch": ".types",
    "PayMethodBodyAllFields": ".types",
    "PayMethodCloud": ".types",
    "PayMethodCredit": ".types",
    "PayMethodStoredMethod": ".types",
    "PayMethodStoredMethodMethod": ".types",
    "PayabliApiResponse": ".types",
    "PayabliApiResponse0": ".types",
    "PayabliApiResponse00": ".types",
    "PayabliApiResponse0000": ".types",
    "PayabliApiResponse00Responsedatanonobject": ".types",
    "PayabliApiResponse0ResponseData": ".types",
    "PayabliApiResponse6": ".types",
    "PayabliApiResponseCustomerQuery": ".types",
    "PayabliApiResponseError400": ".types",
    "PayabliApiResponseError400ResponseData": ".types",
    "PayabliApiResponseGeneric2Part": ".types",
    "PayabliApiResponseGetPaid": ".money_in",
    "PayabliApiResponseImport": ".types",
    "PayabliApiResponseImportResponseData": ".types",
    "PayabliApiResponseMfaBasic": ".types",
    "PayabliApiResponseNotifications": ".types",
    "PayabliApiResponseNotificationsResponseData": ".types",
    "PayabliApiResponseOcr": ".ocr",
    "PayabliApiResponsePaylinks": ".types",
    "PayabliApiResponsePaymentLinks": ".payment_link",
    "PayabliApiResponsePaymethodDelete": ".types",
    "PayabliApiResponsePaymethodDeleteResponseData": ".types",
    "PayabliApiResponseTemplateId": ".types",
    "PayabliApiResponseUserMfa": ".types",
    "PayabliApiResponseVendors": ".types",
    "PayabliCredentials": ".types",
    "PayabliCredentialsPascal": ".types",
    "PayabliPages": ".types",
    "PayeeName": ".types",
    "PaylinkId": ".types",
    "PaymentCategories": ".types",
    "PaymentDetail": ".types",
    "PaymentDetailCredit": ".types",
    "PaymentIdString": ".types",
    "PaymentMethod": ".types",
    "PaymentMethodDomainApiResponse": ".types",
    "PaymentMethodDomainGeneralResponse": ".types",
    "PaymentMethodDomainId": ".types",
    "PaymentPageRequestBody": ".payment_link",
    "PaymentTransStatusDescription": ".types",
    "Paymentid": ".types",
    "PayorDataRequest": ".types",
    "PayorDataResponse": ".types",
    "PayorElement": ".types",
    "PayorFields": ".types",
    "PayorId": ".types",
    "PayoutAverageMonthlyVolume": ".types",
    "PayoutAverageTicketLimit": ".types",
    "PayoutCreditLimit": ".types",
    "PayoutGatewayConnector": ".types",
    "PayoutHighTicketAmount": ".types",
    "PayoutProgram": ".types",
    "PaypointData": ".types",
    "PaypointEntryConfig": ".types",
    "PaypointId": ".types",
    "PaypointMoveRequest": ".paypoint",
    "PaypointName": ".types",
    "PaypointSummary": ".types",
    "Paypointstatus": ".types",
    "PciAttestation": ".types",
    "PendingFeeAmount": ".types",
    "PhoneNumber": ".types",
    "PoiDevice": ".types",
    "PolicyId": ".types",
    "PosCol": ".types",
    "PosRow": ".types",
    "ProcessingSection": ".types",
    "PurchaseOrder": ".types",
    "PushPayLinkRequest": ".types",
    "PushPayLinkRequestEmail": ".types",
    "PushPayLinkRequestSms": ".types",
    "PushPayLinkRequest_Email": ".types",
    "PushPayLinkRequest_Sms": ".types",
    "QueryBatchesDetailResponse": ".query_types",
    "QueryBatchesOutResponse": ".types",
    "QueryBatchesOutResponseRecordsItem": ".types",
    "QueryBatchesResponse": ".query_types",
    "QueryBatchesResponseRecordsItem": ".query_types",
    "QueryBatchesTransfer": ".query_types",
    "QueryBoardingAppsListResponse": ".types",
    "QueryBoardingLinksResponse": ".types",
    "QueryBoardingLinksResponseRecordsItem": ".types",
    "QueryCFeeTransaction": ".types",
    "QueryChargebacksResponse": ".types",
    "QueryChargebacksResponseRecordsItem": ".types",
    "QueryCustomerResponse": ".types",
    "QueryEntrypointResponse": ".types",
    "QueryEntrypointResponseRecordsItem": ".types",
    "QueryInvoiceResponse": ".invoice",
    "QueryInvoiceResponseRecordsItem": ".invoice",
    "QueryPaymentData": ".types",
    "QueryPayoutTransaction": ".types",
    "QueryPayoutTransactionRecordsItem": ".types",
    "QueryPayoutTransactionRecordsItemPaymentData": ".types",
    "QueryPayoutTransactionSummary": ".types",
    "QueryResponse": ".types",
    "QueryResponseData": ".types",
    "QueryResponseItems": ".types",
    "QueryResponseItemsRecordsItem": ".types",
    "QueryResponseNotificationReports": ".types",
    "QueryResponseNotificationReportsRecordsItem": ".types",
    "QueryResponseNotifications": ".types",
    "QueryResponseNotificationsRecordsItem": ".types",
    "QueryResponseSettlements": ".types",
    "QueryResponseSettlementsRecordsItem": ".types",
    "QueryResponseSettlementsSummary": ".types",
    "QueryResponseTransactions": ".types",
    "QueryResponseVendors": ".types",
    "QuerySubscriptionResponse": ".types",
    "QuerySummary": ".types",
    "QuerySummaryNoAmt": ".types",
    "QueryTransactionEvents": ".types",
    "QueryTransactionEventsEventData": ".types",
    "QueryTransactionPayorData": ".types",
    "QueryTransferDetailResponse": ".query_types",
    "QueryTransferResponse": ".query_types",
    "QueryTransferSummary": ".query_types",
    "QueryUserResponse": ".types",
    "ReadOnly": ".types",
    "ReceiptContent": ".types",
    "ReceiptResponse": ".money_in",
    "RecipientEmailNotification": ".types",
    "ReferenceName": ".types",
    "ReferenceTemplateId": ".types",
    "Referenceidtrans": ".types",
    "RefundDetail": ".types",
    "RefundId": ".types",
    "RefundResponse": ".money_in",
    "RefundWithInstructionsResponse": ".money_in",
    "RemitEmail": ".types",
    "Remitaddress1": ".types",
    "Remitaddress2": ".types",
    "Remitcity": ".types",
    "Remitcountry": ".types",
    "Remitstate": ".types",
    "Remitzip": ".types",
    "RemoveDeviceResponse": ".cloud",
    "RemoveSubscriptionResponse": ".subscription",
    "RepCode": ".types",
    "RepName": ".types",
    "RepOffice": ".types",
    "ReplyToEmail": ".types",
    "Replyby": ".types",
    "RequestCreditPaymentMethod": ".money_in",
    "RequestOutAuthorizeInvoiceData": ".money_out_types",
    "RequestOutAuthorizePaymentDetails": ".money_out_types",
    "RequestOutAuthorizeVendorBillingData": ".money_out_types",
    "RequestOutAuthorizeVendorData": ".money_out_types",
    "RequestOutAuthorizeVendorDataOld": ".money_out_types",
    "RequestPaymentAuthorizePaymentMethod": ".money_in",
    "RequestPaymentValidatePaymentMethod": ".money_in",
    "RequestPaymentValidatePaymentMethodMethod": ".money_in",
    "RequestSchedulePaymentMethod": ".subscription",
    "RequestSchedulePaymentMethodInitiator": ".subscription",
    "RequestTokenStorage": ".token_storage",
    "RequestTokenStoragePaymentMethod": ".token_storage",
    "RequiredElement": ".types",
    "ResponseDataRefunds": ".money_in",
    "ResponseText": ".types",
    "Responsecode": ".types",
    "Responsedata": ".types",
    "Responsedatanonobject": ".types",
    "ResultCode": ".types",
    "Resulttext": ".types",
    "Resumable": ".types",
    "RetrievalId": ".types",
    "ReturnedId": ".types",
    "ReverseResponse": ".money_in",
    "RiskAction": ".types",
    "RiskActionCode": ".types",
    "RiskFlagged": ".types",
    "RiskFlaggedOn": ".types",
    "RiskReason": ".types",
    "RiskStatus": ".types",
    "RoomIdNotInUse": ".types",
    "RoutingAccount": ".types",
    "SSection": ".types",
    "SalesCode": ".types",
    "SalesSection": ".types",
    "SaveIfSuccess": ".types",
    "ScheduleDetail": ".types",
    "ScheduleId": ".types",
    "SendInvoiceResponse": ".invoice",
    "Sequence": ".types",
    "ServiceCost": ".types",
    "ServiceUnavailableError": ".errors",
    "Services": ".types",
    "ServicesSection": ".types",
    "SetApprovedBillResponse": ".bill",
    "SetPause": ".subscription",
    "SettingElement": ".types",
    "SettingsQueryRecord": ".types",
    "SettlementStatus": ".types",
    "SettlementStatusPayout": ".types",
    "ShippingFromZip": ".types",
    "Shippingaddress": ".types",
    "Shippingaddressadditional": ".types",
    "Shippingcity": ".types",
    "Shippingcountry": ".types",
    "Shippingstate": ".types",
    "Shippingzip": ".types",
    "SignDate": ".types",
    "Signaturedata": ".types",
    "SignedDocumentReference": ".types",
    "SignerAcceptance": ".types",
    "SignerAddress1": ".types",
    "SignerCity": ".types",
    "SignerCountry": ".types",
    "SignerData": ".types",
    "SignerDataRequest": ".types",
    "SignerDob": ".types",
    "SignerName": ".types",
    "SignerPhone": ".types",
    "SignerSection": ".types",
    "SignerSsn": ".types",
    "SignerState": ".types",
    "SignerZip": ".types",
    "Signeraddress": ".types",
    "Source": ".types",
    "SplitFunding": ".types",
    "SplitFundingContent": ".types",
    "SplitFundingRefundContent": ".types",
    "StatBasicQueryRecord": ".statistic",
    "StateNullable": ".types",
    "StatisticsVendorQueryRecord": ".statistic",
    "Statusnotification": ".types",
    "StoredMethodUsageType": ".types",
    "Storedmethodid": ".types",
    "StringStringKeyValuePair": ".notificationlogs",
    "SubFooter": ".types",
    "SubHeader": ".types",
    "Subdomain": ".types",
    "SubscriptionQueryRecords": ".types",
    "SubscriptionRequestBody": ".subscription",
    "SubscriptionStatsQueryRecord": ".statistic",
    "Subscriptionid": ".types",
    "SummaryCommodityCode": ".types",
    "SummaryOrg": ".types",
    "Target": ".types",
    "Tax": ".types",
    "Taxfillname": ".types",
    "TemplateAdditionalDataField": ".types",
    "TemplateAdditionalDataSection": ".types",
    "TemplateCode": ".types",
    "TemplateContent": ".types",
    "TemplateContentResponse": ".types",
    "TemplateData": ".types",
    "TemplateElement": ".types",
    "TemplateId": ".types",
    "TemplateName": ".types",
    "TemplateQueryRecord": ".types",
    "TemplateQueryResponse": ".types",
    "Temporary": ".token_storage",
    "Terms": ".types",
    "TermsConditions": ".types",
    "Ticketamt": ".types",
    "TierItem": ".types",
    "TierItemPass": ".types",
    "Timezone": ".types",
    "TokenizeAch": ".token_storage",
    "TokenizeCard": ".token_storage",
    "Totalpages": ".types",
    "Totalrecords": ".types",
    "TransRequestBody": ".money_in",
    "TransStatus": ".types",
    "TransactionOutQueryRecord": ".types",
    "TransactionQueryRecords": ".types",
    "TransactionTime": ".types",
    "Transfer": ".types",
    "TransferBankAccount": ".types",
    "TransferDetailRecord": ".query_types",
    "TransferIdentifier": ".types",
    "TransferMessage": ".types",
    "TransferMessageProperties": ".types",
    "TransferQueryResponse": ".types",
    "TransferSummary": ".types",
    "TypeAccount": ".types",
    "TypeResult": ".ocr",
    "UnauthorizedError": ".errors",
    "UnderWritingMethod": ".types",
    "UnderwritingData": ".types",
    "UnderwritingDataResponse": ".types",
    "UpdateNotificationRequest": ".notification",
    "UpdatePaymentMethodDomainRequestWallet": ".payment_method_domain",
    "UpdateSubscriptionResponse": ".subscription",
    "UserData": ".types",
    "UserQueryRecord": ".types",
    "UsrAccess": ".types",
    "UsrStatus": ".types",
    "VCardGetResponse": ".money_out_types",
    "VCardGetResponseAssociatedVendor": ".money_out_types",
    "VCardGetResponseAssociatedVendorBillingData": ".money_out_types",
    "VCardGetResponseAssociatedVendorSummary": ".money_out_types",
    "VCardGetResponseContact": ".money_out_types",
    "VCardQueryResponse": ".types",
    "VCardRecord": ".types",
    "VCardSummary": ".types",
    "ValidateResponse": ".money_in",
    "ValidateResponseData": ".money_in",
    "ValueTemplates": ".types",
    "VendorCheckNumber": ".types",
    "VendorData": ".types",
    "VendorDataResponse": ".types",
    "VendorDataResponsePaymentMethod": ".types",
    "VendorEin": ".types",
    "VendorName1": ".types",
    "VendorName2": ".types",
    "VendorNumber": ".types",
    "VendorOutData": ".types",
    "VendorPaymentMethod": ".types",
    "VendorPaymentMethodString": ".types",
    "VendorPhone": ".types",
    "VendorQueryRecord": ".types",
    "VendorResponseBillingData": ".types",
    "VendorResponseStoredMethod": ".types",
    "VendorResponseSummary": ".types",
    "VendorSummary": ".types",
    "Vendorid": ".types",
    "Vendorstatus": ".types",
    "Visible": ".types",
    "VoidResponse": ".money_in",
    "VoidResponseData": ".money_in",
    "WalletCascade": ".types",
    "WalletIsEnabled": ".types",
    "WebHeaderParameter": ".paypoint",
    "Website": ".types",
    "Whencharged": ".types",
    "Whendelivered": ".types",
    "Whenprovided": ".types",
    "Whenrefunded": ".types",
    "Zip": ".types",
    "__version__": ".version",
    "bill": ".",
    "boarding": ".",
    "charge_backs": ".",
    "check_capture": ".",
    "cloud": ".",
    "customer": ".",
    "export": ".",
    "hosted_payment_pages": ".",
    "import_": ".",
    "invoice": ".",
    "line_item": ".",
    "money_in": ".",
    "money_out": ".",
    "money_out_types": ".",
    "notification": ".",
    "notificationlogs": ".",
    "ocr": ".",
    "organization": ".",
    "payabli": ".client",
    "payabliEnvironment": ".environment",
    "payment_link": ".",
    "payment_method_domain": ".",
    "paypoint": ".",
    "query": ".",
    "query_types": ".",
    "statistic": ".",
    "subscription": ".",
    "templates": ".",
    "token_storage": ".",
    "user": ".",
    "vendor": ".",
    "wallet": ".",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ASection",
    "AcceptOauth",
    "AcceptRegister",
    "AccountNumber",
    "Accountexp",
    "Accountid",
    "AccountingField",
    "Accounttype",
    "Accountzip",
    "Ach",
    "AchAbsorbSection",
    "AchAcceptanceElement",
    "AchFeeSection",
    "AchHolder",
    "AchHolderType",
    "AchLinkTypes",
    "AchPassThroughSection",
    "AchPaymentMethod",
    "AchSecCode",
    "AchSection",
    "AchService",
    "AchSetup",
    "AchTypes",
    "AchTypesPass",
    "AchTypesTiers",
    "AchValidation",
    "Achaccount",
    "Achaccounttype",
    "Achrouting",
    "AddApplicationRequest",
    "AddDeviceResponse",
    "AddMethodResponse",
    "AddMethodResponseResponseData",
    "AddNotificationRequest",
    "AddOrganizationResponse",
    "AddPaymentMethodDomainApiResponse",
    "AddPaymentMethodDomainRequestApplePay",
    "AddPaymentMethodDomainRequestGooglePay",
    "AddResponseResponse",
    "AddSubscriptionResponse",
    "AddUserResponse",
    "AdditionalData",
    "AdditionalDataMap",
    "AdditionalDataString",
    "AddressAddtlNullable",
    "AddressNullable",
    "AmountElement",
    "Annualrevenue",
    "AppId",
    "ApplePayData",
    "ApplePayId",
    "ApplePayMetadata",
    "ApplePayOrganizationUpdateData",
    "ApplePayPaypointRegistrationData",
    "ApplePayStatusData",
    "ApplePayType",
    "AppleWalletData",
    "ApplicationData",
    "ApplicationDataManaged",
    "ApplicationDataManagedContactsItem",
    "ApplicationDataManagedOwnershipItem",
    "ApplicationDataOdp",
    "ApplicationDataOdpContactsItem",
    "ApplicationDataOdpOwnershipItem",
    "ApplicationDataPayIn",
    "ApplicationDataPayInBankData",
    "ApplicationDataPayInContactsItem",
    "ApplicationDataPayInOwnershipItem",
    "ApplicationDataPayInServices",
    "ApplicationDataPayInServicesAch",
    "ApplicationDataPayInServicesCard",
    "ApplicationDetailsRecord",
    "ApplicationDetailsRecordMessagesItem",
    "ApplicationQueryRecord",
    "AssociatedVendor",
    "Asyncpayabli",
    "Attachments",
    "AttestationDate",
    "AuthCapturePayoutResponse",
    "AuthCapturePayoutResponseData",
    "AuthResetUserResponse",
    "AuthResponse",
    "AuthResponseResponseData",
    "Authcode",
    "AuthorizePaymentMethod",
    "AuthorizePayoutBody",
    "AutoElement",
    "Avgmonthly",
    "Avgticketamt",
    "Avsresponsetext",
    "BAddress",
    "BDetails",
    "BSection",
    "BadRequestError",
    "Baddress1",
    "Baddress2",
    "Bank",
    "BankAccountFunction",
    "BankAccountHolderName",
    "BankAccountHolderType",
    "BankData",
    "BankName",
    "BankNickname",
    "BankSection",
    "BasicTable",
    "BasicTemplateElement",
    "BatchDetailResponseRecord",
    "BatchDetailResponseSummary",
    "BatchNumber",
    "BatchSummary",
    "Bcity",
    "Bcountry",
    "BillApprovals",
    "BillData",
    "BillDataPaymentTerms",
    "BillDetailResponse",
    "BillDetailsResponse",
    "BillEvents",
    "BillId",
    "BillItem",
    "BillOptions",
    "BillOutData",
    "BillOutDataScheduledOptions",
    "BillPayOutData",
    "BillPayOutDataRequest",
    "BillQueryRecord2",
    "BillQueryRecord2BillApprovalsItem",
    "BillQueryRecord2PaymentMethod",
    "BillQueryResponse",
    "BillQueryResponseSummary",
    "BillResponse",
    "BillResponseData",
    "BillingAddressAddtlNullable",
    "BillingAddressNullable",
    "BillingCityNullable",
    "BillingCountryNullable",
    "BillingData",
    "BillingDataResponse",
    "BillingFeeDetail",
    "BillingStateNullable",
    "BillingZip",
    "Billitems",
    "Billstatus",
    "BinData",
    "Binperson",
    "Binphone",
    "Binweb",
    "Bnk",
    "BoardingApplicationAttachments",
    "BoardingAverageBillSize",
    "BoardingAvgMonthlyBill",
    "BoardingBusinessFax",
    "BoardingBusinessPhone",
    "BoardingId",
    "BoardingLinkApiResponse",
    "BoardingLinkId",
    "BoardingLinkQueryRecord",
    "BoardingQueryLinks",
    "BoardingStatus",
    "Bphone",
    "Bstate",
    "Bsummary",
    "BuilderData",
    "BulkRetryRequest",
    "BusinessSection",
    "Busstartdate",
    "ButtonElement",
    "ButtonElementSize",
    "Bzip",
    "CList",
    "CaptureAllOutResponse",
    "CaptureAllOutResponseResponseDataItem",
    "CaptureError",
    "CapturePaymentDetails",
    "CaptureRequest",
    "CaptureResponse",
    "CaptureResponseData",
    "CardAcceptanceElement",
    "CardFeeSection",
    "CardFlatSection",
    "CardIcpSection",
    "CardLinkTypes",
    "CardPassThroughSection",
    "CardSection",
    "CardService",
    "CardSetup",
    "CardType",
    "CardTypePass",
    "CardTypes",
    "Cardcvv",
    "Cardexp",
    "Cardholder",
    "Cardnumber",
    "Cardzip",
    "Cascade",
    "CascadeJobDetails",
    "Cash",
    "Category",
    "ChangePswUserResponse",
    "ChargeBackResponse",
    "ChargebackId",
    "ChargebackMessage",
    "ChargebackQueryRecords",
    "Check",
    "CheckCaptureRequest",
    "CheckCaptureResponse",
    "CityNullable",
    "CloudQueryApiResponse",
    "Comments",
    "ConfigureApplePayOrganizationApiResponse",
    "ConfigureApplePaypointApiResponse",
    "ConfigureGooglePaypointApiResponse",
    "ConflictError",
    "ContactElement",
    "Contacts",
    "ContactsField",
    "ContactsResponse",
    "ConvertToken",
    "CountryNullable",
    "CreateAnonymous",
    "CreatedAt",
    "CustomerData",
    "CustomerId",
    "CustomerNumberNullable",
    "CustomerQueryRecords",
    "CustomerQueryRecordsCustomerConsent",
    "CustomerQueryRecordsCustomerConsentECommunication",
    "CustomerQueryRecordsCustomerConsentSms",
    "CustomerStatus",
    "CustomerSummaryRecord",
    "Customeridtrans",
    "Cvvresponsetext",
    "DSection",
    "Datenullable",
    "DatetimeNullable",
    "Dbaname",
    "DeleteItemResponse",
    "DeleteOrganizationResponse",
    "DeletePaymentMethodDomainResponse",
    "DeleteUserResponse",
    "DepositDate",
    "Descriptor",
    "Device",
    "DeviceId",
    "Discount",
    "DisplayProperty",
    "DocumentSection",
    "DocumentSectionTermsAndConditions",
    "DocumentSectionTermsAndConditionsTcLinksItem",
    "DocumentsRef",
    "DomainName",
    "DutyAmount",
    "EditBillResponse",
    "EditMfaUserResponse",
    "EditOrganizationResponse",
    "Ein",
    "Element",
    "Email",
    "Enabled",
    "EnrollmentStatus",
    "EntityId",
    "EntityType",
    "Entry",
    "EntryAttributes",
    "EntrypageId",
    "Entrypointfield",
    "ExpectedDepositDate",
    "ExpectedProcessingDateTime",
    "ExportFormat",
    "ExportFormat1",
    "ExternalPaypointId",
    "ExternalProcessorInformation",
    "FaxNumber",
    "FeeAmount",
    "File",
    "FileContent",
    "FileContentFtype",
    "FileContentImageOnly",
    "Finishtype",
    "ForbiddenError",
    "ForceCustomerCreation",
    "FreightAmount",
    "Frequency",
    "FrequencyList",
    "Frequencynotification",
    "Gatewayfield",
    "GeneralEvents",
    "GetBasicEntryByIdResponse",
    "GetBasicEntryResponse",
    "GetBillResponse",
    "GetEntryConfigResponse",
    "GetInvoiceRecord",
    "GetMethodResponse",
    "GetMethodResponseResponseData",
    "GetMethodResponseResponseDataCustomersItem",
    "GetPaidResponseData",
    "GetPayLinkFromIdResponse",
    "GetPayLinkFromIdResponseResponseData",
    "GooglePayData",
    "GooglePayMetadata",
    "GooglePayPaypointRegistrationData",
    "GooglePayStatusData",
    "GoogleWalletData",
    "HasVcardTransactions",
    "HeaderElement",
    "Highticketamt",
    "Holdername",
    "IdempotencyKey",
    "Identifierfields",
    "Idpaypoint",
    "Initiator",
    "Instrument",
    "InternalReferenceId",
    "InternalServerError",
    "InvalidTransStatusError",
    "InvalidTransStatusErrorType",
    "InvoiceAmount",
    "InvoiceDataRequest",
    "InvoiceElement",
    "InvoiceId",
    "InvoiceNumber",
    "InvoiceNumberResponse",
    "InvoicePaidAmount",
    "InvoiceResponseWithoutData",
    "InvoiceType",
    "Invoicestatus",
    "IpAddress",
    "IsEnabled",
    "IsRoot",
    "IsSameDayAch",
    "IsSuccess",
    "ItemCommodityCode",
    "ItemDescription",
    "ItemProductCode",
    "ItemProductName",
    "ItemUnitofMeasure",
    "JobId",
    "JobStatus",
    "KeyValue",
    "KeyValueArray",
    "KeyValueDuo",
    "LabelElement",
    "Language",
    "LastModified",
    "Legalname",
    "License",
    "Licensestate",
    "LimitRecord",
    "LineItem",
    "LineItemQueryRecord",
    "LinkData",
    "LinkRow",
    "ListOrganizationsResponse",
    "ListPaymentMethodDomainsResponse",
    "LocationCode",
    "LogoutUserResponse",
    "LotNumber",
    "Maddress",
    "Maddress1",
    "Maskedaccount",
    "Mcc",
    "Mcity",
    "Mcountry",
    "MethodElement",
    "MethodElementSettings",
    "MethodElementSettingsApplePay",
    "MethodElementSettingsApplePayButtonStyle",
    "MethodElementSettingsApplePayButtonType",
    "MethodElementSettingsApplePayLanguage",
    "MethodQueryRecords",
    "MethodReferenceId",
    "Methodall",
    "Methodnotification",
    "MethodsList",
    "Mfa",
    "MfaData",
    "MfaMode",
    "MfaValidationCode",
    "MigratePaypointResponse",
    "ModifyApprovalBillResponse",
    "Mstate",
    "Mzip",
    "NameUser",
    "NetAmountstring",
    "Netamountnullable",
    "NoteElement",
    "NotificationContent",
    "NotificationContentEventType",
    "NotificationContentFileFormat",
    "NotificationContentReportName",
    "NotificationId",
    "NotificationLog",
    "NotificationLogDetail",
    "NotificationLogSearchRequest",
    "NotificationQueryRecord",
    "NotificationReportRequest",
    "NotificationReportRequestContent",
    "NotificationReportRequestContentFileFormat",
    "NotificationReportRequestContentReportName",
    "NotificationReportRequestFrequency",
    "NotificationReportRequestMethod",
    "NotificationRequest",
    "NotificationStandardRequest",
    "NotificationStandardRequestContent",
    "NotificationStandardRequestContentEventType",
    "NotificationStandardRequestFrequency",
    "NotificationStandardRequestMethod",
    "OList",
    "OSection",
    "OcrAttachment",
    "OcrBillItem",
    "OcrBillItemAdditionalData",
    "OcrResponseData",
    "OcrResultData",
    "OcrVendor",
    "OcrVendorAdditionalData",
    "OcrVendorBillingData",
    "OdpSetup",
    "OdpSetupProcessingRegion",
    "Operation",
    "OperationResult",
    "OptinStatus",
    "Order",
    "OrderId",
    "Orderdescription",
    "OrgData",
    "OrgParentId",
    "OrgParentName",
    "OrgScope",
    "OrgXScope",
    "Orgaddress",
    "OrganizationId",
    "OrganizationQueryRecord",
    "OrganizationQueryRecordServicesItem",
    "OrganizationUpdates",
    "Orgcity",
    "Orgcountry",
    "Orgentryname",
    "Orgid",
    "Orgidstring",
    "Orgname",
    "Orgstate",
    "Orgtimezone",
    "Orgtype",
    "Orgwebsite",
    "Orgzip",
    "OwnType",
    "OwnerEntityId",
    "OwnerEntityType",
    "Ownerid",
    "Owners",
    "OwnersSection",
    "Ownership",
    "Ownertype",
    "PSection",
    "PageContent",
    "PageElement",
    "PageIdentifier",
    "PageSetting",
    "PagelinkSetting",
    "Pagesize",
    "PairFiles",
    "PayCategory",
    "PayMethodAch",
    "PayMethodBodyAllFields",
    "PayMethodCloud",
    "PayMethodCredit",
    "PayMethodStoredMethod",
    "PayMethodStoredMethodMethod",
    "PayabliApiResponse",
    "PayabliApiResponse0",
    "PayabliApiResponse00",
    "PayabliApiResponse0000",
    "PayabliApiResponse00Responsedatanonobject",
    "PayabliApiResponse0ResponseData",
    "PayabliApiResponse6",
    "PayabliApiResponseCustomerQuery",
    "PayabliApiResponseError400",
    "PayabliApiResponseError400ResponseData",
    "PayabliApiResponseGeneric2Part",
    "PayabliApiResponseGetPaid",
    "PayabliApiResponseImport",
    "PayabliApiResponseImportResponseData",
    "PayabliApiResponseMfaBasic",
    "PayabliApiResponseNotifications",
    "PayabliApiResponseNotificationsResponseData",
    "PayabliApiResponseOcr",
    "PayabliApiResponsePaylinks",
    "PayabliApiResponsePaymentLinks",
    "PayabliApiResponsePaymethodDelete",
    "PayabliApiResponsePaymethodDeleteResponseData",
    "PayabliApiResponseTemplateId",
    "PayabliApiResponseUserMfa",
    "PayabliApiResponseVendors",
    "PayabliCredentials",
    "PayabliCredentialsPascal",
    "PayabliPages",
    "PayeeName",
    "PaylinkId",
    "PaymentCategories",
    "PaymentDetail",
    "PaymentDetailCredit",
    "PaymentIdString",
    "PaymentMethod",
    "PaymentMethodDomainApiResponse",
    "PaymentMethodDomainGeneralResponse",
    "PaymentMethodDomainId",
    "PaymentPageRequestBody",
    "PaymentTransStatusDescription",
    "Paymentid",
    "PayorDataRequest",
    "PayorDataResponse",
    "PayorElement",
    "PayorFields",
    "PayorId",
    "PayoutAverageMonthlyVolume",
    "PayoutAverageTicketLimit",
    "PayoutCreditLimit",
    "PayoutGatewayConnector",
    "PayoutHighTicketAmount",
    "PayoutProgram",
    "PaypointData",
    "PaypointEntryConfig",
    "PaypointId",
    "PaypointMoveRequest",
    "PaypointName",
    "PaypointSummary",
    "Paypointstatus",
    "PciAttestation",
    "PendingFeeAmount",
    "PhoneNumber",
    "PoiDevice",
    "PolicyId",
    "PosCol",
    "PosRow",
    "ProcessingSection",
    "PurchaseOrder",
    "PushPayLinkRequest",
    "PushPayLinkRequestEmail",
    "PushPayLinkRequestSms",
    "PushPayLinkRequest_Email",
    "PushPayLinkRequest_Sms",
    "QueryBatchesDetailResponse",
    "QueryBatchesOutResponse",
    "QueryBatchesOutResponseRecordsItem",
    "QueryBatchesResponse",
    "QueryBatchesResponseRecordsItem",
    "QueryBatchesTransfer",
    "QueryBoardingAppsListResponse",
    "QueryBoardingLinksResponse",
    "QueryBoardingLinksResponseRecordsItem",
    "QueryCFeeTransaction",
    "QueryChargebacksResponse",
    "QueryChargebacksResponseRecordsItem",
    "QueryCustomerResponse",
    "QueryEntrypointResponse",
    "QueryEntrypointResponseRecordsItem",
    "QueryInvoiceResponse",
    "QueryInvoiceResponseRecordsItem",
    "QueryPaymentData",
    "QueryPayoutTransaction",
    "QueryPayoutTransactionRecordsItem",
    "QueryPayoutTransactionRecordsItemPaymentData",
    "QueryPayoutTransactionSummary",
    "QueryResponse",
    "QueryResponseData",
    "QueryResponseItems",
    "QueryResponseItemsRecordsItem",
    "QueryResponseNotificationReports",
    "QueryResponseNotificationReportsRecordsItem",
    "QueryResponseNotifications",
    "QueryResponseNotificationsRecordsItem",
    "QueryResponseSettlements",
    "QueryResponseSettlementsRecordsItem",
    "QueryResponseSettlementsSummary",
    "QueryResponseTransactions",
    "QueryResponseVendors",
    "QuerySubscriptionResponse",
    "QuerySummary",
    "QuerySummaryNoAmt",
    "QueryTransactionEvents",
    "QueryTransactionEventsEventData",
    "QueryTransactionPayorData",
    "QueryTransferDetailResponse",
    "QueryTransferResponse",
    "QueryTransferSummary",
    "QueryUserResponse",
    "ReadOnly",
    "ReceiptContent",
    "ReceiptResponse",
    "RecipientEmailNotification",
    "ReferenceName",
    "ReferenceTemplateId",
    "Referenceidtrans",
    "RefundDetail",
    "RefundId",
    "RefundResponse",
    "RefundWithInstructionsResponse",
    "RemitEmail",
    "Remitaddress1",
    "Remitaddress2",
    "Remitcity",
    "Remitcountry",
    "Remitstate",
    "Remitzip",
    "RemoveDeviceResponse",
    "RemoveSubscriptionResponse",
    "RepCode",
    "RepName",
    "RepOffice",
    "ReplyToEmail",
    "Replyby",
    "RequestCreditPaymentMethod",
    "RequestOutAuthorizeInvoiceData",
    "RequestOutAuthorizePaymentDetails",
    "RequestOutAuthorizeVendorBillingData",
    "RequestOutAuthorizeVendorData",
    "RequestOutAuthorizeVendorDataOld",
    "RequestPaymentAuthorizePaymentMethod",
    "RequestPaymentValidatePaymentMethod",
    "RequestPaymentValidatePaymentMethodMethod",
    "RequestSchedulePaymentMethod",
    "RequestSchedulePaymentMethodInitiator",
    "RequestTokenStorage",
    "RequestTokenStoragePaymentMethod",
    "RequiredElement",
    "ResponseDataRefunds",
    "ResponseText",
    "Responsecode",
    "Responsedata",
    "Responsedatanonobject",
    "ResultCode",
    "Resulttext",
    "Resumable",
    "RetrievalId",
    "ReturnedId",
    "ReverseResponse",
    "RiskAction",
    "RiskActionCode",
    "RiskFlagged",
    "RiskFlaggedOn",
    "RiskReason",
    "RiskStatus",
    "RoomIdNotInUse",
    "RoutingAccount",
    "SSection",
    "SalesCode",
    "SalesSection",
    "SaveIfSuccess",
    "ScheduleDetail",
    "ScheduleId",
    "SendInvoiceResponse",
    "Sequence",
    "ServiceCost",
    "ServiceUnavailableError",
    "Services",
    "ServicesSection",
    "SetApprovedBillResponse",
    "SetPause",
    "SettingElement",
    "SettingsQueryRecord",
    "SettlementStatus",
    "SettlementStatusPayout",
    "ShippingFromZip",
    "Shippingaddress",
    "Shippingaddressadditional",
    "Shippingcity",
    "Shippingcountry",
    "Shippingstate",
    "Shippingzip",
    "SignDate",
    "Signaturedata",
    "SignedDocumentReference",
    "SignerAcceptance",
    "SignerAddress1",
    "SignerCity",
    "SignerCountry",
    "SignerData",
    "SignerDataRequest",
    "SignerDob",
    "SignerName",
    "SignerPhone",
    "SignerSection",
    "SignerSsn",
    "SignerState",
    "SignerZip",
    "Signeraddress",
    "Source",
    "SplitFunding",
    "SplitFundingContent",
    "SplitFundingRefundContent",
    "StatBasicQueryRecord",
    "StateNullable",
    "StatisticsVendorQueryRecord",
    "Statusnotification",
    "StoredMethodUsageType",
    "Storedmethodid",
    "StringStringKeyValuePair",
    "SubFooter",
    "SubHeader",
    "Subdomain",
    "SubscriptionQueryRecords",
    "SubscriptionRequestBody",
    "SubscriptionStatsQueryRecord",
    "Subscriptionid",
    "SummaryCommodityCode",
    "SummaryOrg",
    "Target",
    "Tax",
    "Taxfillname",
    "TemplateAdditionalDataField",
    "TemplateAdditionalDataSection",
    "TemplateCode",
    "TemplateContent",
    "TemplateContentResponse",
    "TemplateData",
    "TemplateElement",
    "TemplateId",
    "TemplateName",
    "TemplateQueryRecord",
    "TemplateQueryResponse",
    "Temporary",
    "Terms",
    "TermsConditions",
    "Ticketamt",
    "TierItem",
    "TierItemPass",
    "Timezone",
    "TokenizeAch",
    "TokenizeCard",
    "Totalpages",
    "Totalrecords",
    "TransRequestBody",
    "TransStatus",
    "TransactionOutQueryRecord",
    "TransactionQueryRecords",
    "TransactionTime",
    "Transfer",
    "TransferBankAccount",
    "TransferDetailRecord",
    "TransferIdentifier",
    "TransferMessage",
    "TransferMessageProperties",
    "TransferQueryResponse",
    "TransferSummary",
    "TypeAccount",
    "TypeResult",
    "UnauthorizedError",
    "UnderWritingMethod",
    "UnderwritingData",
    "UnderwritingDataResponse",
    "UpdateNotificationRequest",
    "UpdatePaymentMethodDomainRequestWallet",
    "UpdateSubscriptionResponse",
    "UserData",
    "UserQueryRecord",
    "UsrAccess",
    "UsrStatus",
    "VCardGetResponse",
    "VCardGetResponseAssociatedVendor",
    "VCardGetResponseAssociatedVendorBillingData",
    "VCardGetResponseAssociatedVendorSummary",
    "VCardGetResponseContact",
    "VCardQueryResponse",
    "VCardRecord",
    "VCardSummary",
    "ValidateResponse",
    "ValidateResponseData",
    "ValueTemplates",
    "VendorCheckNumber",
    "VendorData",
    "VendorDataResponse",
    "VendorDataResponsePaymentMethod",
    "VendorEin",
    "VendorName1",
    "VendorName2",
    "VendorNumber",
    "VendorOutData",
    "VendorPaymentMethod",
    "VendorPaymentMethodString",
    "VendorPhone",
    "VendorQueryRecord",
    "VendorResponseBillingData",
    "VendorResponseStoredMethod",
    "VendorResponseSummary",
    "VendorSummary",
    "Vendorid",
    "Vendorstatus",
    "Visible",
    "VoidResponse",
    "VoidResponseData",
    "WalletCascade",
    "WalletIsEnabled",
    "WebHeaderParameter",
    "Website",
    "Whencharged",
    "Whendelivered",
    "Whenprovided",
    "Whenrefunded",
    "Zip",
    "__version__",
    "bill",
    "boarding",
    "charge_backs",
    "check_capture",
    "cloud",
    "customer",
    "export",
    "hosted_payment_pages",
    "import_",
    "invoice",
    "line_item",
    "money_in",
    "money_out",
    "money_out_types",
    "notification",
    "notificationlogs",
    "ocr",
    "organization",
    "payabli",
    "payabliEnvironment",
    "payment_link",
    "payment_method_domain",
    "paypoint",
    "query",
    "query_types",
    "statistic",
    "subscription",
    "templates",
    "token_storage",
    "user",
    "vendor",
    "wallet",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.ach_holder_type import AchHolderType
from ...types.ach_sec_code import AchSecCode
from ...types.initiator import Initiator
from ...types.stored_method_usage_type import StoredMethodUsageType


class AuthorizePaymentMethod(UniversalBaseModel):
    """
    Payment method object for vendor payouts.
    - `{ method: "managed" }` - Managed payment method
    - `{ method: "vcard" }` - Virtual card payment method
    - `{ method: "check" }` - Check payment method
    - `{ method: "ach", achHolder: "...", achRouting: "...", achAccount: "...", achAccountType: "..." }` - ACH payment method with bank details
    - `{ method: "ach", storedMethodId: "..." }` - ACH payment method using stored method ID
    """

    method: str = pydantic.Field()
    """
    Payment method type - "managed", "vcard", "check", or "ach"
    """

    ach_holder: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="achHolder")] = pydantic.Field(
        default=None
    )
    """
    Account holder name for ACH payments. Required when method is "ach" and not using `storedMethodId`.
    """

    ach_routing: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="achRouting")] = pydantic.Field(
        default=None
    )
    """
    Bank routing number for ACH payments. Required when method is "ach" and not using `storedMethodId`.
    """

    ach_account: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="achAccount")] = pydantic.Field(
        default=None
    )
    """
    Bank account number for ACH payments. Required when method is "ach" and not using `storedMethodId`.
    """

    ach_account_type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="achAccountType")] = (
        pydantic.Field(default=None)
    )
    """
    Account type for ACH payments ("checking" or "savings"). Required when method is "ach" and not using `storedMethodId`.
    """

    ach_code: typing_extensions.Annotated[typing.Optional[AchSecCode], FieldMetadata(alias="achCode")] = None
    ach_holder_type: typing_extensions.Annotated[
        typing.Optional[AchHolderType], FieldMetadata(alias="achHolderType")
    ] = None
    stored_method_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="storedMethodId")] = (
        pydantic.Field(default=None)
    )
    """
    ID of the stored ACH payment method. Only applicable when method is `ach`. Use this to reference a previously saved ACH method instead of providing bank details directly.
    """

    initiator: typing.Optional[Initiator] = None
    stored_method_usage_type: typing_extensions.Annotated[
        typing.Optional[StoredMethodUsageType], FieldMetadata(alias="storedMethodUsageType")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .query_payout_transaction_records_item import QueryPayoutTransactionRecordsItem
from .query_payout_transaction_summary import QueryPayoutTransactionSummary


class QueryPayoutTransaction(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from payabli import (
        BillPayOutData,
        PaymentDetail,
        QueryPayoutTransaction,
        QueryPayoutTransactionRecordsItem,
        QueryPayoutTransactionRecordsItemPaymentData,
        QueryPayoutTransactionSummary,
        QueryTransactionEvents,
        VendorQueryRecord,
    )

    QueryPayoutTransaction(
        records=[
            QueryPayoutTransactionRecordsItem(
                batch_number="BT-2024321",
                bills=[BillPayOutData()],
                card_token="CardToken",
                check_number="12345",
                comments="Deposit for materials",
                created_at=datetime.datetime.fromisoformat(
                    "2022-07-01 15:00:01+00:00",
                ),
                entry_name="d193cf9a46",
                events=[QueryTransactionEvents()],
                external_paypoint_id="Paypoint-100",
                fee_amount=10.25,
                gateway="TSYS",
                id_out=236,
                last_updated=datetime.datetime.fromisoformat(
                    "2022-07-01 15:00:01+00:00",
                ),
                net_amount=3762.87,
                parent_org_name="PropertyManager Pro",
                payment_data=QueryPayoutTransactionRecordsItemPaymentData(
                    payment_details=PaymentDetail(
                        total_amount=100.0,
                    ),
                ),
                payment_id="12345678910",
                payment_method="ach",
                payment_status="Processed",
                paypoint_dbaname="Sunshine Gutters",
                paypoint_legalname="Sunshine Services, LLC",
                source="api",
                status=1,
                total_amount=110.25,
                vendor=VendorQueryRecord(
                    additional_data={
                        "key1": {"key": "value"},
                        "key2": {"key": "value"},
                        "key3": {"key": "value"},
                    },
                    created_date=datetime.datetime.fromisoformat(
                        "2022-07-01 15:00:01+00:00",
                    ),
                ),
            )
        ],
        summary=QueryPayoutTransactionSummary(
            total_pages=391,
            total_records=7803,
            total_amount=21435.95,
            total_net_amount=21435.95,
            total_paid=1,
            total_paid_amount=4.0,
            total_canceled=1743,
            total_canceled_amount=4515.0,
            total_captured=138,
            total_captured_amount=542.0,
            total_authorized=4139,
            total_authorized_amount=11712.35,
            total_processing=1780,
            total_processing_amount=4660.6,
            total_open=2,
            total_open_amount=2.0,
            total_on_hold=0,
            total_on_hold_amount=0.0,
            page_size=20,
        ),
    )
    """

    records: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryPayoutTransactionRecordsItem]], FieldMetadata(alias="Records")
    ] = None
    summary: typing_extensions.Annotated[
        typing.Optional[QueryPayoutTransactionSummary], FieldMetadata(alias="Summary")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_invoice_record import GetInvoiceRecord
    from .invoice_data_request import InvoiceDataRequest
    from .invoice_id import InvoiceId
    from .invoice_number_response import InvoiceNumberResponse
    from .invoice_paid_amount import InvoicePaidAmount
    from .invoice_response_without_data import InvoiceResponseWithoutData
    from .query_invoice_response import QueryInvoiceResponse
    from .query_invoice_response_records_item import QueryInvoiceResponseRecordsItem
    from .send_invoice_response import SendInvoiceResponse
_dynamic_imports: typing.Dict[str, str] = {
    "GetInvoiceRecord": ".get_invoice_record",
    "InvoiceDataRequest": ".invoice_data_request",
    "InvoiceId": ".invoice_id",
    "InvoiceNumberResponse": ".invoice_number_response",
    "InvoicePaidAmount": ".invoice_paid_amount",
    "InvoiceResponseWithoutData": ".invoice_response_without_data",
    "QueryInvoiceResponse": ".query_invoice_response",
    "QueryInvoiceResponseRecordsItem": ".query_invoice_response_records_item",
    "SendInvoiceResponse": ".send_invoice_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetInvoiceRecord",
    "InvoiceDataRequest",
    "InvoiceId",
    "InvoiceNumberResponse",
    "InvoicePaidAmount",
    "InvoiceResponseWithoutData",
    "QueryInvoiceResponse",
    "QueryInvoiceResponseRecordsItem",
    "SendInvoiceResponse",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .bill_out_data import BillOutData
    from .bill_out_data_scheduled_options import BillOutDataScheduledOptions
    from .bill_response import BillResponse
    from .bill_response_data import BillResponseData
    from .edit_bill_response import EditBillResponse
    from .get_bill_response import GetBillResponse
    from .modify_approval_bill_response import ModifyApprovalBillResponse
    from .set_approved_bill_response import SetApprovedBillResponse
_dynamic_imports: typing.Dict[str, str] = {
    "BillOutData": ".bill_out_data",
    "BillOutDataScheduledOptions": ".bill_out_data_scheduled_options",
    "BillResponse": ".bill_response",
    "BillResponseData": ".bill_response_data",
    "EditBillResponse": ".edit_bill_response",
    "GetBillResponse": ".get_bill_response",
    "ModifyApprovalBillResponse": ".modify_approval_bill_response",
    "SetApprovedBillResponse": ".set_approved_bill_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BillOutData",
    "BillOutDataScheduledOptions",
    "BillResponse",
    "BillResponseData",
    "EditBillResponse",
    "GetBillResponse",
    "ModifyApprovalBillResponse",
    "SetApprovedBillResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.customer_id import CustomerId
from ...types.method_reference_id import MethodReferenceId
from ...types.result_code import ResultCode
from ...types.resulttext import Resulttext


class AddMethodResponseResponseData(UniversalBaseModel):
    customer_id: typing_extensions.Annotated[typing.Optional[CustomerId], FieldMetadata(alias="CustomerId")] = (
        pydantic.Field(default=None)
    )
    """
    Internal unique ID of customer owner of the stored method.  
    
    Returns `0` if the method wasn't assigned to an existing customer or no customer was created."
    """

    method_reference_id: typing_extensions.Annotated[
        typing.Optional[MethodReferenceId], FieldMetadata(alias="methodReferenceId")
    ] = None
    reference_id: typing_extensions.Annotated[
        typing.Optional[MethodReferenceId], FieldMetadata(alias="ReferenceId")
    ] = pydantic.Field(default=None)
    """
    Stored method identifier in Payabli platform. This ID is used to manage the stored method.
    """

    result_code: typing_extensions.Annotated[typing.Optional[ResultCode], FieldMetadata(alias="ResultCode")] = None
    result_text: typing_extensions.Annotated[typing.Optional[Resulttext], FieldMetadata(alias="ResultText")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.item_commodity_code import ItemCommodityCode
from ..types.item_description import ItemDescription
from ..types.item_product_code import ItemProductCode
from ..types.item_product_name import ItemProductName
from ..types.item_unitof_measure import ItemUnitofMeasure
from ..types.line_item_query_record import LineItemQueryRecord
from ..types.payabli_api_response_6 import PayabliApiResponse6
from ..types.query_response_items import QueryResponseItems
from .raw_client import AsyncRawLineItemClient, RawLineItemClient
from .types.delete_item_response import DeleteItemResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class LineItemClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawLineItemClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawLineItemClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawLineItemClient
        """
        return self._raw_client

    def add_item(
        self,
        entry: str,
        *,
        item_cost: float,
        item_qty: int,
        idempotency_key: typing.Optional[str] = None,
        item_categories: typing.Optional[typing.Sequence[typing.Optional[str]]] = OMIT,
        item_commodity_code: typing.Optional[ItemCommodityCode] = OMIT,
        item_description: typing.Optional[ItemDescription] = OMIT,
        item_mode: typing.Optional[int] = OMIT,
        item_product_code: typing.Optional[ItemProductCode] = OMIT,
        item_product_name: typing.Optional[ItemProductName] = OMIT,
        item_unit_of_measure: typing.Optional[ItemUnitofMeasure] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponse6:
        """
        Adds products and services to an entrypoint's catalog. These are used as line items for invoicing and transactions. In the response, "responseData" displays the item's code.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        item_cost : float
            Item or product price per unit.

        item_qty : int
            Quantity of item or product.

        idempotency_key : typing.Optional[str]
            A unique ID you can include to prevent duplicating objects or transactions if a request is sent more than once. This key isn't generated in Payabli, you must generate it yourself.

        item_categories : typing.Optional[typing.Sequence[typing.Optional[str]]]
            Array of tags classifying item or product.

        item_commodity_code : typing.Optional[ItemCommodityCode]

        item_description : typing.Optional[ItemDescription]

        item_mode : typing.Optional[int]
            Internal class of item or product: value '0' is only for invoices, '1' for bills, and '2' is common for both.

        item_product_code : typing.Optional[ItemProductCode]

        item_product_name : typing.Optional[ItemProductName]

        item_unit_of_measure : typing.Optional[ItemUnitofMeasure]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponse6
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.line_item.add_item(
            entry="47cae3d74",
            item_product_code="M-DEPOSIT",
            item_product_name="Materials deposit",
            item_description="Deposit for materials",
            item_commodity_code="010",
            item_unit_of_measure="SqFt",
            item_cost=12.45,
            item_qty=1,
            item_mode=0,
        )
        """
        _response = self._raw_client.add_item(
            entry,
            item_cost=item_cost,
            item_qty=item_qty,
            idempotency_key=idempotency_key,
            item_categories=item_categories,
            item_commodity_code=item_commodity_code,
            item_description=item_description,
            item_mode=item_mode,
            item_product_code=item_product_code,
            item_product_name=item_product_name,
            item_unit_of_measure=item_unit_of_measure,
            request_options=request_options,
        )
        return _response.data

    def delete_item(
        self, line_item_id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteItemResponse:
        """
        Deletes an item.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteItemResponse
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.line_item.delete_item(
            line_item_id=700,
        )
        """
        _response = self._raw_client.delete_item(line_item_id, request_options=request_options)
        return _response.data

    def get_item(
        self, line_item_id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> LineItemQueryRecord:
        """
        Gets an item by ID.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LineItemQueryRecord
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.line_item.get_item(
            line_item_id=700,
        )
        """
        _response = self._raw_client.get_item(line_item_id, request_options=request_options)
        return _response.data

    def list_line_items(
        self,
        entry: str,
        *,
        from_record: typing.Optional[int] = None,
        limit_record: typing.Optional[int] = None,
        parameters: typing.Optional[typing.Dict[str, typing.Optional[str]]] = None,
        sort_by: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> QueryResponseItems:
        """
        Retrieves a list of line items and their details from an entrypoint. Line items are also known as items, products, and services. Use filters to limit results.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        from_record : typing.Optional[int]
            The number of records to skip before starting to collect the result set.

        limit_record : typing.Optional[int]
            Max number of records to return for the query. Use `0` or negative value to return all records.

        parameters : typing.Optional[typing.Dict[str, typing.Optional[str]]]

            Collection of field names, conditions, and values used to filter the query
            <Info>
              **You must remove `parameters=` from the request before you send it, otherwise Payabli will ignore the filters.**

              Because of a technical limitation, you can't make a request that includes filters from the API console on this page. The response won't be filtered. Instead, copy the request, remove `parameters=` and run the request in a different client.

              For example:

              --url https://api-sandbox.payabli.com/api/Query/transactions/org/236?parameters=totalAmount(gt)=1000&limitRecord=20

              should become:

              --url https://api-sandbox.payabli.com/api/Query/transactions/org/236?totalAmount(gt)=1000&limitRecord=20

            </Info>
            See [Filters and Conditions Reference](/developers/developer-guides/pay-ops-reporting-engine-overview#filters-and-conditions-reference) for help.

            List of field names accepted:

              - `categories` (ct, nct)
              - `code` (ne, eq, ct, nct)
              - `commodityCode` (ne, eq, ct, nct)
              - `createdDate` (gt, ge, lt, le, eq, ne)
              - `description` (ne, eq, ct, nct)
              - `externalPaypointID` (ct, nct, ne, eq)
              - `mode` (eq, ne)
              - `name` (ne, eq, ct, nct)
              - `orgName` (ne, eq, ct, nct)
              - `paypointDba` (ne, eq, ct, nct)
              - `paypointId` (ne, eq)
              - `paypointLegal` (ne, eq, ct, nct)
              - `quantity` (gt, ge, lt, le, eq, ne)
              - `uom` (ne, eq, ct, nct)
              - `updatedDate` (gt, ge, lt, le, eq, ne)
              - `value` (gt, ge, lt, le, eq, ne)

            List of comparison accepted - enclosed between parentheses:

            - eq or empty => equal
            - gt => greater than
            - ge => greater or equal
            - lt => less than
            - le => less or equal
            - ne => not equal
            - ct => contains
            - nct => not contains
            - in => inside array separated by "|"
            - nin => not inside array separated by "|"

            List of parameters accepted:
            - limitRecord : max number of records for query (default="20", "0" or negative value for all)
            - fromRecord : initial record in query

            Example: name(ct)=john return all records with name containing john

        sort_by : typing.Optional[str]
            The field name to use for sorting results. Use `desc(field_name)` to sort descending by `field_name`, and use `asc(field_name)` to sort ascending by `field_name`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        QueryResponseItems
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.line_item.list_line_items(
            entry="8cfec329267",
            from_record=251,
            limit_record=0,
            sort_by="desc(field_name)",
        )
        """
        _response = self._raw_client.list_line_items(
            entry,
            from_record=from_record,
            limit_record=limit_record,
            parameters=parameters,
            sort_by=sort_by,
            request_options=request_options,
        )
        return _response.data

    def update_item(
        self,
        line_item_id: int,
        *,
        item_cost: float,
        item_qty: int,
        item_categories: typing.Optional[typing.Sequence[typing.Optional[str]]] = OMIT,
        item_commodity_code: typing.Optional[ItemCommodityCode] = OMIT,
        item_description: typing.Optional[ItemDescription] = OMIT,
        item_mode: typing.Optional[int] = OMIT,
        item_product_code: typing.Optional[ItemProductCode] = OMIT,
        item_product_name: typing.Optional[ItemProductName] = OMIT,
        item_unit_of_measure: typing.Optional[ItemUnitofMeasure] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponse6:
        """
        Updates an item.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        item_cost : float
            Item or product price per unit.

        item_qty : int
            Quantity of item or product.

        item_categories : typing.Optional[typing.Sequence[typing.Optional[str]]]
            Array of tags classifying item or product.

        item_commodity_code : typing.Optional[ItemCommodityCode]

        item_description : typing.Optional[ItemDescription]

        item_mode : typing.Optional[int]
            Internal class of item or product: value '0' is only for invoices, '1' for bills, and '2' is common for both.

        item_product_code : typing.Optional[ItemProductCode]

        item_product_name : typing.Optional[ItemProductName]

        item_unit_of_measure : typing.Optional[ItemUnitofMeasure]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponse6
            Success

        Examples
        --------
        from payabli import payabli

        client = payabli(
            api_key="YOUR_API_KEY",
        )
        client.line_item.update_item(
            line_item_id=700,
            item_cost=12.45,
            item_qty=1,
        )
        """
        _response = self._raw_client.update_item(
            line_item_id,
            item_cost=item_cost,
            item_qty=item_qty,
            item_categories=item_categories,
            item_commodity_code=item_commodity_code,
            item_description=item_description,
            item_mode=item_mode,
            item_product_code=item_product_code,
            item_product_name=item_product_name,
            item_unit_of_measure=item_unit_of_measure,
            request_options=request_options,
        )
        return _response.data


class AsyncLineItemClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawLineItemClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawLineItemClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawLineItemClient
        """
        return self._raw_client

    async def add_item(
        self,
        entry: str,
        *,
        item_cost: float,
        item_qty: int,
        idempotency_key: typing.Optional[str] = None,
        item_categories: typing.Optional[typing.Sequence[typing.Optional[str]]] = OMIT,
        item_commodity_code: typing.Optional[ItemCommodityCode] = OMIT,
        item_description: typing.Optional[ItemDescription] = OMIT,
        item_mode: typing.Optional[int] = OMIT,
        item_product_code: typing.Optional[ItemProductCode] = OMIT,
        item_product_name: typing.Optional[ItemProductName] = OMIT,
        item_unit_of_measure: typing.Optional[ItemUnitofMeasure] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponse6:
        """
        Adds products and services to an entrypoint's catalog. These are used as line items for invoicing and transactions. In the response, "responseData" displays the item's code.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        item_cost : float
            Item or product price per unit.

        item_qty : int
            Quantity of item or product.

        idempotency_key : typing.Optional[str]
            A unique ID you can include to prevent duplicating objects or transactions if a request is sent more than once. This key isn't generated in Payabli, you must generate it yourself.

        item_categories : typing.Optional[typing.Sequence[typing.Optional[str]]]
            Array of tags classifying item or product.

        item_commodity_code : typing.Optional[ItemCommodityCode]

        item_description : typing.Optional[ItemDescription]

        item_mode : typing.Optional[int]
            Internal class of item or product: value '0' is only for invoices, '1' for bills, and '2' is common for both.

        item_product_code : typing.Optional[ItemProductCode]

        item_product_name : typing.Optional[ItemProductName]

        item_unit_of_measure : typing.Optional[ItemUnitofMeasure]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponse6
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.line_item.add_item(
                entry="47cae3d74",
                item_product_code="M-DEPOSIT",
                item_product_name="Materials deposit",
                item_description="Deposit for materials",
                item_commodity_code="010",
                item_unit_of_measure="SqFt",
                item_cost=12.45,
                item_qty=1,
                item_mode=0,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_item(
            entry,
            item_cost=item_cost,
            item_qty=item_qty,
            idempotency_key=idempotency_key,
            item_categories=item_categories,
            item_commodity_code=item_commodity_code,
            item_description=item_description,
            item_mode=item_mode,
            item_product_code=item_product_code,
            item_product_name=item_product_name,
            item_unit_of_measure=item_unit_of_measure,
            request_options=request_options,
        )
        return _response.data

    async def delete_item(
        self, line_item_id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteItemResponse:
        """
        Deletes an item.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteItemResponse
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.line_item.delete_item(
                line_item_id=700,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_item(line_item_id, request_options=request_options)
        return _response.data

    async def get_item(
        self, line_item_id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> LineItemQueryRecord:
        """
        Gets an item by ID.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LineItemQueryRecord
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.line_item.get_item(
                line_item_id=700,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_item(line_item_id, request_options=request_options)
        return _response.data

    async def list_line_items(
        self,
        entry: str,
        *,
        from_record: typing.Optional[int] = None,
        limit_record: typing.Optional[int] = None,
        parameters: typing.Optional[typing.Dict[str, typing.Optional[str]]] = None,
        sort_by: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> QueryResponseItems:
        """
        Retrieves a list of line items and their details from an entrypoint. Line items are also known as items, products, and services. Use filters to limit results.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        from_record : typing.Optional[int]
            The number of records to skip before starting to collect the result set.

        limit_record : typing.Optional[int]
            Max number of records to return for the query. Use `0` or negative value to return all records.

        parameters : typing.Optional[typing.Dict[str, typing.Optional[str]]]

            Collection of field names, conditions, and values used to filter the query
            <Info>
              **You must remove `parameters=` from the request before you send it, otherwise Payabli will ignore the filters.**

              Because of a technical limitation, you can't make a request that includes filters from the API console on this page. The response won't be filtered. Instead, copy the request, remove `parameters=` and run the request in a different client.

              For example:

              --url https://api-sandbox.payabli.com/api/Query/transactions/org/236?parameters=totalAmount(gt)=1000&limitRecord=20

              should become:

              --url https://api-sandbox.payabli.com/api/Query/transactions/org/236?totalAmount(gt)=1000&limitRecord=20

            </Info>
            See [Filters and Conditions Reference](/developers/developer-guides/pay-ops-reporting-engine-overview#filters-and-conditions-reference) for help.

            List of field names accepted:

              - `categories` (ct, nct)
              - `code` (ne, eq, ct, nct)
              - `commodityCode` (ne, eq, ct, nct)
              - `createdDate` (gt, ge, lt, le, eq, ne)
              - `description` (ne, eq, ct, nct)
              - `externalPaypointID` (ct, nct, ne, eq)
              - `mode` (eq, ne)
              - `name` (ne, eq, ct, nct)
              - `orgName` (ne, eq, ct, nct)
              - `paypointDba` (ne, eq, ct, nct)
              - `paypointId` (ne, eq)
              - `paypointLegal` (ne, eq, ct, nct)
              - `quantity` (gt, ge, lt, le, eq, ne)
              - `uom` (ne, eq, ct, nct)
              - `updatedDate` (gt, ge, lt, le, eq, ne)
              - `value` (gt, ge, lt, le, eq, ne)

            List of comparison accepted - enclosed between parentheses:

            - eq or empty => equal
            - gt => greater than
            - ge => greater or equal
            - lt => less than
            - le => less or equal
            - ne => not equal
            - ct => contains
            - nct => not contains
            - in => inside array separated by "|"
            - nin => not inside array separated by "|"

            List of parameters accepted:
            - limitRecord : max number of records for query (default="20", "0" or negative value for all)
            - fromRecord : initial record in query

            Example: name(ct)=john return all records with name containing john

        sort_by : typing.Optional[str]
            The field name to use for sorting results. Use `desc(field_name)` to sort descending by `field_name`, and use `asc(field_name)` to sort ascending by `field_name`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        QueryResponseItems
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.line_item.list_line_items(
                entry="8cfec329267",
                from_record=251,
                limit_record=0,
                sort_by="desc(field_name)",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_line_items(
            entry,
            from_record=from_record,
            limit_record=limit_record,
            parameters=parameters,
            sort_by=sort_by,
            request_options=request_options,
        )
        return _response.data

    async def update_item(
        self,
        line_item_id: int,
        *,
        item_cost: float,
        item_qty: int,
        item_categories: typing.Optional[typing.Sequence[typing.Optional[str]]] = OMIT,
        item_commodity_code: typing.Optional[ItemCommodityCode] = OMIT,
        item_description: typing.Optional[ItemDescription] = OMIT,
        item_mode: typing.Optional[int] = OMIT,
        item_product_code: typing.Optional[ItemProductCode] = OMIT,
        item_product_name: typing.Optional[ItemProductName] = OMIT,
        item_unit_of_measure: typing.Optional[ItemUnitofMeasure] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PayabliApiResponse6:
        """
        Updates an item.

        Parameters
        ----------
        line_item_id : int
            ID for the line item (also known as a product, service, or item).

        item_cost : float
            Item or product price per unit.

        item_qty : int
            Quantity of item or product.

        item_categories : typing.Optional[typing.Sequence[typing.Optional[str]]]
            Array of tags classifying item or product.

        item_commodity_code : typing.Optional[ItemCommodityCode]

        item_description : typing.Optional[ItemDescription]

        item_mode : typing.Optional[int]
            Internal class of item or product: value '0' is only for invoices, '1' for bills, and '2' is common for both.

        item_product_code : typing.Optional[ItemProductCode]

        item_product_name : typing.Optional[ItemProductName]

        item_unit_of_measure : typing.Optional[ItemUnitofMeasure]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PayabliApiResponse6
            Success

        Examples
        --------
        import asyncio

        from payabli import Asyncpayabli

        client = Asyncpayabli(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.line_item.update_item(
                line_item_id=700,
                item_cost=12.45,
                item_qty=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_item(
            line_item_id,
            item_cost=item_cost,
            item_qty=item_qty,
            item_categories=item_categories,
            item_commodity_code=item_commodity_code,
            item_description=item_description,
            item_mode=item_mode,
            item_product_code=item_product_code,
            item_product_name=item_product_name,
            item_unit_of_measure=item_unit_of_measure,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.service_unavailable_error import ServiceUnavailableError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.entry import Entry
from ..types.payabli_api_response import PayabliApiResponse
from .types.check_capture_response import CheckCaptureResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCheckCaptureClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def check_processing(
        self,
        *,
        entry_point: Entry,
        front_image: str,
        rear_image: str,
        check_amount: int,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CheckCaptureResponse]:
        """
        Captures a check for Remote Deposit Capture (RDC) using the provided check images and details. This endpoint handles the OCR extraction of check data including MICR, routing number, account number, and amount. See the [RDC guide](/developers/developer-guides/pay-in-rdc) for more details.

        Parameters
        ----------
        entry_point : Entry

        front_image : str
            Base64-encoded front check image. Must be JPEG or PNG format and less than 1MB. Image must show the entire check clearly with no partial, blurry, or illegible portions.

        rear_image : str
            Base64-encoded rear check image. Must be JPEG or PNG format and less than 1MB. Image must show the entire check clearly with no partial, blurry, or illegible portions.

        check_amount : int
            Check amount in cents (maximum 32-bit integer value).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CheckCaptureResponse]
            Success response with check processing results.
        """
        _response = self._client_wrapper.httpx_client.request(
            "CheckCapture/CheckProcessing",
            method="POST",
            json={
                "entryPoint": entry_point,
                "frontImage": front_image,
                "rearImage": rear_image,
                "checkAmount": check_amount,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CheckCaptureResponse,
                    parse_obj_as(
                        type_=CheckCaptureResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCheckCaptureClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def check_processing(
        self,
        *,
        entry_point: Entry,
        front_image: str,
        rear_image: str,
        check_amount: int,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CheckCaptureResponse]:
        """
        Captures a check for Remote Deposit Capture (RDC) using the provided check images and details. This endpoint handles the OCR extraction of check data including MICR, routing number, account number, and amount. See the [RDC guide](/developers/developer-guides/pay-in-rdc) for more details.

        Parameters
        ----------
        entry_point : Entry

        front_image : str
            Base64-encoded front check image. Must be JPEG or PNG format and less than 1MB. Image must show the entire check clearly with no partial, blurry, or illegible portions.

        rear_image : str
            Base64-encoded rear check image. Must be JPEG or PNG format and less than 1MB. Image must show the entire check clearly with no partial, blurry, or illegible portions.

        check_amount : int
            Check amount in cents (maximum 32-bit integer value).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CheckCaptureResponse]
            Success response with check processing results.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "CheckCapture/CheckProcessing",
            method="POST",
            json={
                "entryPoint": entry_point,
                "frontImage": front_image,
                "rearImage": rear_image,
                "checkAmount": check_amount,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CheckCaptureResponse,
                    parse_obj_as(
                        type_=CheckCaptureResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .cash import Cash
from .check import Check
from .pay_method_ach import PayMethodAch
from .pay_method_body_all_fields import PayMethodBodyAllFields
from .pay_method_cloud import PayMethodCloud
from .pay_method_credit import PayMethodCredit
from .pay_method_stored_method import PayMethodStoredMethod

PaymentMethod = typing.Union[
    PayMethodCredit, PayMethodAch, PayMethodStoredMethod, PayMethodCloud, Check, Cash, PayMethodBodyAllFields
]
